@@ -4,27 +4,29 @@
 
 #include "AccountMigrationManager.h"
 
-#include "AccountManager.h"
-#include "Algorithms.h"
-#include "Encryption.h"
-#include "FutureUtils.h"
-#include "RegistrationManager.h"
-#include "RosterDb.h"
-#include "RosterItem.h"
-#include "RosterModel.h"
-#include "Settings.h"
-#include "XmlUtils.h"
-
+// Qt
 #include <QDir>
 #include <QDomDocument>
 #include <QFile>
 #include <QSaveFile>
 #include <QStandardPaths>
 #include <QUrl>
-
+// QXmpp
 #include <QXmppConfiguration.h>
 #include <QXmppMovedManager.h>
 #include <QXmppPubSubManager.h>
+// Kaidan
+#include "AccountDb.h"
+#include "AccountManager.h"
+#include "Algorithms.h"
+#include "Encryption.h"
+#include "FutureUtils.h"
+#include "KaidanCoreLog.h"
+#include "RegistrationManager.h"
+#include "RosterDb.h"
+#include "RosterItem.h"
+#include "RosterModel.h"
+#include "XmlUtils.h"
 
 #define readDataElement(NAME)                                                                                                                                  \
     if (!XmlUtils::Reader::text(rootElement.firstChildElement(QStringLiteral(#NAME)), data.NAME)) {                                                            \
@@ -102,14 +104,22 @@ struct ClientRosterItemSettings {
 
 struct ClientConfiguration {
     ClientConfiguration() = default;
-    explicit ClientConfiguration(const Settings &settings)
+    explicit ClientConfiguration(const Account &account)
     {
-        authHost = settings.authHost();
-        authPort = settings.authPort();
-        authTlsErrorsIgnored = settings.authTlsErrorsIgnored();
-        authTlsRequirement = settings.authTlsRequirement();
-        authJid = settings.authJid();
-        authPassword = settings.authPassword();
+        jid = account.jid;
+        password = account.password;
+        host = account.host;
+        port = account.port;
+        tlsErrorsIgnored = account.tlsErrorsIgnored;
+        tlsRequirement = account.tlsRequirement;
+        passwordVisibility = account.passwordVisibility;
+        encryption = account.encryption;
+        automaticMediaDownloadsRule = account.automaticMediaDownloadsRule;
+        name = account.name;
+        contactNotificationRule = account.contactNotificationRule;
+        groupChatNotificationRule = account.groupChatNotificationRule;
+        geoLocationMapPreviewEnabled = account.geoLocationMapPreviewEnabled;
+        geoLocationMapService = account.geoLocationMapService;
     }
 
     static std::variant<ClientConfiguration, QXmppError> fromDom(const QDomElement &rootElement)
@@ -119,12 +129,20 @@ struct ClientConfiguration {
 
         ClientConfiguration data;
 
-        readDataElement(authHost);
-        readDataElement(authPort);
-        readDataElement(authTlsErrorsIgnored);
-        readDataElement(authTlsRequirement);
-        readDataElement(authJid);
-        readDataElement(authPassword);
+        readDataElement(jid);
+        readDataElement(password);
+        readDataElement(host);
+        readDataElement(port);
+        readDataElement(tlsErrorsIgnored);
+        readDataElement(tlsRequirement);
+        readDataElement(passwordVisibility);
+        readDataElement(encryption);
+        readDataElement(automaticMediaDownloadsRule);
+        readDataElement(name);
+        readDataElement(contactNotificationRule);
+        readDataElement(groupChatNotificationRule);
+        readDataElement(geoLocationMapPreviewEnabled);
+        readDataElement(geoLocationMapService);
 
         return data;
     }
@@ -133,12 +151,20 @@ struct ClientConfiguration {
     {
         writer.writeStartElement(s_old_configuration.toString());
         writer.writeDefaultNamespace(s_kaidan_ns.toString());
-        writeDataElement(authHost);
-        writeDataElement(authPort);
-        writeDataElement(authTlsErrorsIgnored);
-        writeDataElement(authTlsRequirement);
-        writeDataElement(authJid);
-        writeDataElement(authPassword);
+        writeDataElement(jid);
+        writeDataElement(password);
+        writeDataElement(host);
+        writeDataElement(port);
+        writeDataElement(tlsErrorsIgnored);
+        writeDataElement(tlsRequirement);
+        writeDataElement(passwordVisibility);
+        writeDataElement(encryption);
+        writeDataElement(automaticMediaDownloadsRule);
+        writeDataElement(name);
+        writeDataElement(contactNotificationRule);
+        writeDataElement(groupChatNotificationRule);
+        writeDataElement(geoLocationMapPreviewEnabled);
+        writeDataElement(geoLocationMapService);
         writer.writeEndElement();
     }
 
@@ -146,45 +172,53 @@ struct ClientConfiguration {
     {
         QXmppConfiguration configuration;
 
-        if (authHost) {
-            configuration.setHost(*authHost);
+        if (jid) {
+            configuration.setJid(*jid);
         }
 
-        if (authPort) {
-            configuration.setPort(*authPort);
+        if (password) {
+            configuration.setPassword(*password);
         }
 
-        if (authTlsErrorsIgnored) {
-            configuration.setIgnoreSslErrors(*authTlsErrorsIgnored);
+        if (host) {
+            configuration.setHost(*host);
         }
 
-        if (authTlsRequirement) {
-            configuration.setStreamSecurityMode(*authTlsRequirement);
+        if (port) {
+            configuration.setPort(*port);
         }
 
-        if (authJid) {
-            configuration.setJid(*authJid);
+        if (tlsErrorsIgnored) {
+            configuration.setIgnoreSslErrors(*tlsErrorsIgnored);
         }
 
-        if (authPassword) {
-            configuration.setPassword(*authPassword);
+        if (tlsRequirement) {
+            configuration.setStreamSecurityMode(*tlsRequirement);
         }
 
         return configuration;
     }
 
-    std::optional<QString> authHost;
-    std::optional<quint16> authPort;
-    std::optional<bool> authTlsErrorsIgnored;
-    std::optional<QXmppConfiguration::StreamSecurityMode> authTlsRequirement;
-    std::optional<QString> authJid;
-    std::optional<QString> authPassword;
+    std::optional<QString> jid;
+    std::optional<QString> password;
+    std::optional<QString> host;
+    std::optional<quint16> port;
+    std::optional<bool> tlsErrorsIgnored;
+    std::optional<QXmppConfiguration::StreamSecurityMode> tlsRequirement;
+    std::optional<Kaidan::PasswordVisibility> passwordVisibility;
+    std::optional<Encryption::Enum> encryption;
+    std::optional<Account::AutomaticMediaDownloadsRule> automaticMediaDownloadsRule;
+    std::optional<QString> name;
+    std::optional<Account::ContactNotificationRule> contactNotificationRule;
+    std::optional<Account::GroupChatNotificationRule> groupChatNotificationRule;
+    std::optional<bool> geoLocationMapPreviewEnabled;
+    std::optional<Account::GeoLocationMapService> geoLocationMapService;
 };
 
 struct ClientSettings {
     ClientSettings() = default;
-    explicit ClientSettings(Settings *settings, const QList<RosterItem> &rosterItems)
-        : oldConfiguration(*settings)
+    explicit ClientSettings(const Account &account, const QList<RosterItem> &rosterItems)
+        : oldConfiguration(account)
         , roster(transform(rosterItems, [](const RosterItem &item) {
             return ClientRosterItemSettings(item);
         }))
@@ -279,9 +313,9 @@ public:
         connect(this, &PublishMovedStatementClient::finished, this, &QObject::deleteLater);
         connect(this, &PublishMovedStatementClient::finished, this, [](const QXmppClient::EmptyResult &result) {
             if (const auto error = std::get_if<QXmppError>(&result)) {
-                qDebug("%s: Publishing failed - %ls", Q_FUNC_INFO, qUtf16Printable(error->description));
+                qCDebug(KAIDAN_CORE_LOG, "%s: Publishing failed - %ls", Q_FUNC_INFO, qUtf16Printable(error->description));
             } else {
-                qDebug("%s: Published successfully", Q_FUNC_INFO);
+                qCDebug(KAIDAN_CORE_LOG, "%s: Published successfully", Q_FUNC_INFO);
             }
         });
     }
@@ -314,7 +348,7 @@ private:
 
     void onErrorOccurred(const QXmppError &error)
     {
-        qDebug("%s: %ls", Q_FUNC_INFO, qUtf16Printable(error.description));
+        qCDebug(KAIDAN_CORE_LOG, "%s: %ls", Q_FUNC_INFO, qUtf16Printable(error.description));
 
         if (isConnected()) {
             disconnectFromServer();
@@ -477,25 +511,26 @@ void AccountMigrationManager::continueMigration(const QVariant &userData)
                             .then(this,
                                   [this,
                                    fail,
+                                   newJid = AccountManager::instance()->account().jid,
+                                   oldJid = m_migrationData->account.accountJid(),
                                    configuration = clientSettings->oldConfiguration.toXmppConfiguration(),
                                    contacts = clientSettings->rosterContacts()](auto &&result) {
                                       if (const auto error = std::get_if<QXmppError>(&result)) {
                                           fail(error->description);
                                       } else {
-                                          publishMovedStatement(configuration, m_migrationData->account.accountJid())
-                                              .then(this, [this, fail, contacts](auto &&result) {
-                                                  if (const auto error = std::get_if<QXmppError>(&result)) {
-                                                      fail(error->description);
-                                                  } else {
-                                                      notifyContacts(contacts, m_migrationData->account.accountJid()).then(this, [&](auto &&result) {
-                                                          if (const auto error = std::get_if<QXmppError>(&result)) {
-                                                              fail(error->description);
-                                                          } else {
-                                                              continueMigration();
-                                                          }
-                                                      });
-                                                  }
-                                              });
+                                          publishMovedStatement(configuration, newJid).then(this, [this, fail, contacts, oldJid](auto &&result) {
+                                              if (const auto error = std::get_if<QXmppError>(&result)) {
+                                                  fail(error->description);
+                                              } else {
+                                                  notifyContacts(contacts, oldJid).then(this, [&](auto &&result) {
+                                                      if (const auto error = std::get_if<QXmppError>(&result)) {
+                                                          fail(error->description);
+                                                      } else {
+                                                          continueMigration();
+                                                      }
+                                                  });
+                                              }
+                                          });
                                       }
                                   });
                     } else {
@@ -518,7 +553,7 @@ void AccountMigrationManager::cancelMigration()
             const auto accountManager = AccountManager::instance();
 
             // If the stored JID differs from the cached one, reconnect with the stored one.
-            if (accountManager->jid() != m_worker->caches()->settings->authJid()) {
+            if (accountManager->hasNewAccount()) {
                 // Disconnect from any server that the client is connecting to because of a login
                 // attempt.
                 if (m_worker->xmppClient()->state() == QXmppClient::ConnectingState) {
@@ -527,9 +562,9 @@ void AccountMigrationManager::cancelMigration()
 
                 // Resetting the cached JID is needed to load the stored JID via
                 // AccountManager::loadConnectionData().
-                accountManager->setJid({});
+                accountManager->resetNewAccount();
 
-                if (accountManager->loadConnectionData()) {
+                if (accountManager->hasEnoughCredentialsForLogin()) {
                     m_worker->logIn();
                 }
             }
@@ -557,9 +592,10 @@ bool AccountMigrationManager::saveAccountDataToDisk(const QXmppExportData &data)
     QFile file(filePath);
 
     if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-        qDebug("Account could not be migrated: Could not open account file '%ls' for writing: %ls",
-               qUtf16Printable(filePath),
-               qUtf16Printable(file.errorString()));
+        qCDebug(KAIDAN_CORE_LOG,
+                "Account could not be migrated: Could not open account file '%ls' for writing: %ls",
+                qUtf16Printable(filePath),
+                qUtf16Printable(file.errorString()));
         return false;
     }
 
@@ -569,9 +605,10 @@ bool AccountMigrationManager::saveAccountDataToDisk(const QXmppExportData &data)
 
     if (writer.hasError()) {
         file.remove();
-        qDebug("Account could not be migrated: Could not write account data to file '%ls': %ls",
-               qUtf16Printable(filePath),
-               qUtf16Printable(file.errorString()));
+        qCDebug(KAIDAN_CORE_LOG,
+                "Account could not be migrated: Could not write account data to file '%ls': %ls",
+                qUtf16Printable(filePath),
+                qUtf16Printable(file.errorString()));
         return false;
     }
 
@@ -584,25 +621,30 @@ bool AccountMigrationManager::restoreAccountDataFromDisk(QXmppExportData &data)
     QFile file(filePath);
 
     if (!file.open(QIODevice::ReadOnly)) {
-        qDebug("Account could not be migrated: Could not open account file '%ls' for reading: %ls",
-               qUtf16Printable(filePath),
-               qUtf16Printable(file.errorString()));
+        qCDebug(KAIDAN_CORE_LOG,
+                "Account could not be migrated: Could not open account file '%ls' for reading: %ls",
+                qUtf16Printable(filePath),
+                qUtf16Printable(file.errorString()));
         return false;
     }
 
     QDomDocument document;
 
     if (const auto res = document.setContent(&file, QDomDocument::ParseOption::UseNamespaceProcessing); !res) {
-        qDebug("Account could not be migrated: Could not parse account data from '%ls': %ls", qUtf16Printable(filePath), qUtf16Printable(res.errorMessage));
+        qCDebug(KAIDAN_CORE_LOG,
+                "Account could not be migrated: Could not parse account data from '%ls': %ls",
+                qUtf16Printable(filePath),
+                qUtf16Printable(res.errorMessage));
         return false;
     }
 
     const auto result = QXmppExportData::fromDom(document.documentElement());
 
     if (const auto error = std::get_if<QXmppError>(&result)) {
-        qDebug("Account could not be migrated: Could not read account data from file '%ls': %ls",
-               qUtf16Printable(filePath),
-               qUtf16Printable(error->description));
+        qCDebug(KAIDAN_CORE_LOG,
+                "Account could not be migrated: Could not read account data from file '%ls': %ls",
+                qUtf16Printable(filePath),
+                qUtf16Printable(error->description));
         return false;
     }
 
@@ -613,7 +655,49 @@ bool AccountMigrationManager::restoreAccountDataFromDisk(QXmppExportData &data)
 
 QXmppTask<AccountMigrationManager::ImportResult> AccountMigrationManager::importClientSettingsTask(const ClientSettings &settings)
 {
-    return runAsyncTask(this, Kaidan::instance(), [settings]() -> ImportResult {
+    return runAsyncTask(this, Kaidan::instance(), [jid = AccountManager::instance()->account().jid, settings]() -> ImportResult {
+        AccountDb::instance()->updateAccount(jid, [accountSettings = settings.oldConfiguration](Account &account) {
+            if (accountSettings.tlsErrorsIgnored) {
+                account.tlsErrorsIgnored = *accountSettings.tlsErrorsIgnored;
+            }
+
+            if (accountSettings.tlsRequirement) {
+                account.tlsRequirement = *accountSettings.tlsRequirement;
+            }
+
+            if (accountSettings.passwordVisibility) {
+                account.passwordVisibility = *accountSettings.passwordVisibility;
+            }
+
+            if (accountSettings.encryption) {
+                account.encryption = *accountSettings.encryption;
+            }
+
+            if (accountSettings.automaticMediaDownloadsRule) {
+                account.automaticMediaDownloadsRule = *accountSettings.automaticMediaDownloadsRule;
+            }
+
+            if (accountSettings.name) {
+                account.name = *accountSettings.name;
+            }
+
+            if (accountSettings.contactNotificationRule) {
+                account.contactNotificationRule = *accountSettings.contactNotificationRule;
+            }
+
+            if (accountSettings.groupChatNotificationRule) {
+                account.groupChatNotificationRule = *accountSettings.groupChatNotificationRule;
+            }
+
+            if (accountSettings.geoLocationMapPreviewEnabled) {
+                account.geoLocationMapPreviewEnabled = *accountSettings.geoLocationMapPreviewEnabled;
+            }
+
+            if (accountSettings.geoLocationMapService) {
+                account.geoLocationMapService = *accountSettings.geoLocationMapService;
+            }
+        });
+
         for (const ClientRosterItemSettings &itemSettings : settings.roster) {
             RosterDb::instance()->updateItem(itemSettings.bareJid, [itemSettings](RosterItem &item) {
                 item.encryption = itemSettings.encryption.value_or(item.encryption);
@@ -631,8 +715,8 @@ QXmppTask<AccountMigrationManager::ImportResult> AccountMigrationManager::import
 
 QXmppTask<AccountMigrationManager::ExportResult> AccountMigrationManager::exportClientSettingsTask()
 {
-    return runAsyncTask(this, Kaidan::instance(), [settings = m_worker->caches()->settings]() -> ExportResult {
-        return ClientSettings(settings, RosterModel::instance()->items());
+    return runAsyncTask(this, Kaidan::instance(), [account = AccountManager::instance()->account()]() -> ExportResult {
+        return ClientSettings(account, RosterModel::instance()->items());
     });
 }
 
