@@ -4,8 +4,8 @@
 
 #include "AccountTrustMessageUriGenerator.h"
 
+// Kaidan
 #include "EncryptionController.h"
-#include "FutureUtils.h"
 
 AccountTrustMessageUriGenerator::AccountTrustMessageUriGenerator(QObject *parent)
     : TrustMessageUriGenerator(parent)
@@ -32,25 +32,25 @@ void AccountTrustMessageUriGenerator::handleKeysChanged(const QString &accountJi
 
 void AccountTrustMessageUriGenerator::updateKeys()
 {
-    await(EncryptionController::instance()->ownKey(jid()), this, [this](QString &&key) {
+    EncryptionController::instance()->ownKey(jid()).then(this, [this](QString &&key) {
         QList<QString> authenticatedKeys = {key};
 
-        await(EncryptionController::instance()->keys(jid(), {jid()}, QXmpp::TrustLevel::ManuallyDistrusted | QXmpp::TrustLevel::Authenticated),
-              this,
-              [this, authenticatedKeys](QHash<QString, QHash<QString, QXmpp::TrustLevel>> &&keys) mutable {
-                  const auto keyIds = keys.value(jid());
-                  QList<QString> distrustedKeys;
+        EncryptionController::instance()
+            ->keys(jid(), {jid()}, QXmpp::TrustLevel::ManuallyDistrusted | QXmpp::TrustLevel::Authenticated)
+            .then(this, [this, authenticatedKeys](QHash<QString, QHash<QString, QXmpp::TrustLevel>> &&keys) mutable {
+                const auto keyIds = keys.value(jid());
+                QList<QString> distrustedKeys;
 
-                  for (auto itr = keyIds.cbegin(); itr != keyIds.cend(); ++itr) {
-                      if (itr.value() == QXmpp::TrustLevel::Authenticated) {
-                          authenticatedKeys.append(itr.key());
-                      } else {
-                          distrustedKeys.append(itr.key());
-                      }
-                  }
+                for (auto itr = keyIds.cbegin(); itr != keyIds.cend(); ++itr) {
+                    if (itr.value() == QXmpp::TrustLevel::Authenticated) {
+                        authenticatedKeys.append(itr.key());
+                    } else {
+                        distrustedKeys.append(itr.key());
+                    }
+                }
 
-                  setKeys(authenticatedKeys, distrustedKeys);
-              });
+                setKeys(authenticatedKeys, distrustedKeys);
+            });
     });
 }
 
