@@ -9,12 +9,11 @@
 
 // Qt
 #include <QCryptographicHash>
-#include <QDebug>
 #include <QDir>
 #include <QStandardPaths>
 #include <QUrl>
 // Kaidan
-#include "kaidan_debug.h"
+#include "KaidanCoreLog.h"
 
 AvatarFileStorage::AvatarFileStorage(QObject *parent)
     : QObject(parent)
@@ -54,7 +53,7 @@ AvatarFileStorage::AvatarFileStorage(QObject *parent)
             };
         }
     } catch (...) {
-        qCDebug(KAIDAN_LOG) << "[AvatarFileStorage] Error in" << avatarFilePath << "(avatar list file)";
+        qCDebug(KAIDAN_CORE_LOG) << "Error in" << avatarFilePath << "(avatar list file)";
     }
 }
 
