@@ -12,6 +12,7 @@
 #include "FutureUtils.h"
 #include "GroupChatController.h"
 #include "Kaidan.h"
+#include "KaidanCoreLog.h"
 #include "Notifications.h"
 #include "QmlUtils.h"
 #include "RosterManager.h"
@@ -67,7 +68,7 @@ QHash<int, QByteArray> ChatHintModel::roleNames() const
 QVariant ChatHintModel::data(const QModelIndex &index, int role) const
 {
     if (!hasIndex(index.row(), index.column(), index.parent())) {
-        qWarning() << "Could not get data from ChatHintModel:" << index << role;
+        qCWarning(KAIDAN_CORE_LOG) << "Could not get data from ChatHintModel:" << index << role;
         return {};
     }
 
@@ -83,7 +84,7 @@ QVariant ChatHintModel::data(const QModelIndex &index, int role) const
         return chatHint.loadingDescription;
     }
 
-    qWarning("[ChatHintModel] Invalid role requested!");
+    qCWarning(KAIDAN_CORE_LOG, "Invalid role requested!");
     return {};
 }
 
@@ -300,6 +301,7 @@ int ChatHintModel::addConnectToServerChatHint(bool loading)
 void ChatHintModel::addAllowPresenceSubscriptionChatHint(const QXmppPresence &request)
 {
     const QString text = [&request]() {
+        const auto jid = ChatController::instance()->chatJid();
         const auto displayName = ChatController::instance()->rosterItem().displayName();
         const auto appendedText = request.statusText().isEmpty() ? QString() : QStringLiteral(": %1").arg(request.statusText());
         const auto oldJid = request.oldJid();
@@ -310,8 +312,9 @@ void ChatHintModel::addAllowPresenceSubscriptionChatHint(const QXmppPresence &re
         }
 
         const auto oldDisplayName = RosterModel::instance()->findItem(oldJid)->displayName();
-        return tr("Your contact %1 is %2 now and would like to receive your personal data such as availability, devices and other personal information again%3")
-            .arg(oldDisplayName, displayName, appendedText);
+        return tr("Your contact %1 (%2) is %3 (%4) now and would like to receive your personal data such as availability, devices and other personal "
+                  "information again%5")
+            .arg(oldDisplayName, oldJid, displayName, jid, appendedText);
     }();
 
     const auto chatHint = ChatHint{
