@@ -7,6 +7,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "ClientWorker.h"
+
 // Qt
 #include <QGuiApplication>
 #include <QNetworkAccessManager>
@@ -43,8 +44,8 @@
 #include "AvatarFileStorage.h"
 #include "DiscoveryManager.h"
 #include "EncryptionController.h"
-#include "FutureUtils.h"
 #include "Kaidan.h"
+#include "KaidanCoreLog.h"
 #include "LogHandler.h"
 #include "MediaUtils.h"
 #include "MessageController.h"
@@ -58,7 +59,6 @@
 #include "VCardCache.h"
 #include "VCardManager.h"
 #include "VersionManager.h"
-#include "kaidan_debug.h"
 
 ClientWorker::Caches::Caches(QObject *parent)
     : settings(new Settings(parent))
@@ -121,7 +121,7 @@ ClientWorker::ClientWorker(Caches *caches, Database *database, bool enableLoggin
     connect(m_client, &QXmppClient::errorOccurred, this, &ClientWorker::onConnectionError);
 
     connect(m_client, &QXmppClient::credentialsChanged, this, [this]() {
-        m_caches->settings->setAuthCredentials(m_client->configuration().credentials());
+        AccountManager::instance()->setAuthCredentials(m_client->configuration().credentials());
     });
 
     connect(Kaidan::instance(), &Kaidan::logInRequested, this, &ClientWorker::logIn);
@@ -156,7 +156,7 @@ void ClientWorker::startTask(const std::function<void()> &task)
         // credentials are available. That way, the variable can already be set locally
         // during account initialization (like during registration) and set on the server
         // after the first login.
-        if (!AccountManager::instance()->hasNewCredentials() && m_client->state() != QXmppClient::ConnectingState)
+        if (!AccountManager::instance()->hasNewAccount() && m_client->state() != QXmppClient::ConnectingState)
             logIn();
     }
 }
@@ -165,74 +165,85 @@ void ClientWorker::finishTask()
 {
     // If m_activeTasks > 0, there are still running tasks.
     // If m_activeTasks = 0, all tasks are finished (the tasks may have finished directly).
-    if (m_activeTasks > 0 && --m_activeTasks == 0 && !AccountManager::instance()->hasNewCredentials())
+    if (m_activeTasks > 0 && --m_activeTasks == 0 && !AccountManager::instance()->hasNewAccount())
         logOut();
 }
 
 void ClientWorker::logIn()
 {
-    const auto jid = AccountManager::instance()->jid();
+    const auto accountManager = AccountManager::instance();
+    const auto account = accountManager->account();
+    const auto jid = account.jid;
+
     m_atmManager->setAccountJid(jid);
     m_omemoDb->setAccountJid(jid);
 
-    await(
-        EncryptionController::instance(),
-        []() {
-            return EncryptionController::instance()->load();
-        },
-        this,
-        [this]() {
-            if (!m_isFirstLoginAfterStart || m_caches->settings->authOnline()) {
-                // Store the latest online state which is restored when opening Kaidan again after closing.
-                m_caches->settings->setAuthOnline(true);
+    auto proceedLogIn = [this, accountManager, account]() {
+        runOnThread(EncryptionController::instance(), [this, accountManager, account]() {
+            EncryptionController::instance()->load().then([this, accountManager, account]() {
+                if (!m_isFirstLoginAfterStart || account.online) {
+                    // Store the latest online state which is restored when opening Kaidan again after closing.
+                    accountManager->setAuthOnline(true);
 
-                QXmppConfiguration config;
-                config.setResource(AccountManager::instance()->jidResource());
-                config.setCredentials(m_caches->settings->authCredentials());
-                config.setPassword(AccountManager::instance()->password());
-                config.setAutoAcceptSubscriptions(false);
+                    QXmppConfiguration config;
+                    config.setResource(account.jidResource());
+                    config.setCredentials(account.credentials);
+                    config.setPassword(account.password);
+                    config.setAutoAcceptSubscriptions(false);
 
-                // Servers using LDAP do not support SASL PLAIN authentication.
-                config.setDisabledSaslMechanisms({});
+                    // Servers using LDAP do not support SASL PLAIN authentication.
+                    config.setDisabledSaslMechanisms({});
 
-                connectToServer(config);
-            }
+                    connectToServer(config);
+                }
 
-            m_isFirstLoginAfterStart = false;
+                m_isFirstLoginAfterStart = false;
+            });
         });
+    };
+
+    // Reset the locally cached OMEMO data after an account migration to allow a new OMEMO setup.
+    if (const auto oldAccountJid = m_client->configuration().jidBare(); !oldAccountJid.isEmpty() && oldAccountJid != jid) {
+        runOnThread(EncryptionController::instance(), [this, proceedLogIn]() {
+            EncryptionController::instance()->resetLocally().then(this, proceedLogIn);
+        });
+    } else {
+        proceedLogIn();
+    }
 }
 
 void ClientWorker::connectToServer(QXmppConfiguration config)
 {
+    const auto accountManager = AccountManager::instance();
+    const auto account = accountManager->account();
+
     switch (m_client->state()) {
     case QXmppClient::ConnectingState:
-        qCDebug(KAIDAN_LOG) << "[main] Tried to connect even if already connecting! Nothing is done.";
+        qCDebug(KAIDAN_CORE_LOG) << "Tried to connect even if already connecting! Nothing is done.";
         break;
     case QXmppClient::ConnectedState:
-        qCDebug(KAIDAN_LOG) << "[main] Tried to connect even if already connected! Disconnecting first and connecting afterwards.";
+        qCDebug(KAIDAN_CORE_LOG) << "Tried to connect even if already connected! Disconnecting first and connecting afterwards.";
         m_isReconnecting = true;
         m_configToBeUsedOnNextConnect = config;
         logOut();
         break;
     case QXmppClient::DisconnectedState:
-        config.setJid(AccountManager::instance()->jid());
-        config.setStreamSecurityMode(m_caches->settings->authTlsRequirement());
-        config.setIgnoreSslErrors(m_caches->settings->authTlsErrorsIgnored());
-        config.setResourcePrefix(m_caches->settings->authJidResourcePrefix());
-        config.setSasl2UserAgent(m_caches->accountManager->userAgent());
+        config.setJid(account.jid);
+        config.setStreamSecurityMode(account.tlsRequirement);
+        config.setIgnoreSslErrors(account.tlsErrorsIgnored);
+        config.setResourcePrefix(account.resourcePrefix);
+        config.setSasl2UserAgent(accountManager->userAgent());
 
-        auto host = AccountManager::instance()->host();
-        if (!host.isEmpty()) {
-            config.setHost(host);
+        if (!account.host.isEmpty()) {
+            config.setHost(account.host);
         }
 
-        auto port = AccountManager::instance()->port();
-        if (port != PORT_AUTODETECT) {
-            config.setPort(port);
+        if (account.port != PORT_AUTODETECT) {
+            config.setPort(account.port);
 
             // Set the JID's domain part as the host if no custom host is set.
-            if (host.isEmpty()) {
-                config.setHost(QXmppUtils::jidToDomain(AccountManager::instance()->jid()));
+            if (account.host.isEmpty()) {
+                config.setHost(QXmppUtils::jidToDomain(account.jid));
             }
         }
 
@@ -255,7 +266,7 @@ void ClientWorker::logOut(bool isApplicationBeingClosed)
 {
     // Store the latest online state which is restored when opening Kaidan again after closing.
     if (!isApplicationBeingClosed) {
-        m_caches->settings->setAuthOnline(false);
+        AccountManager::instance()->setAuthOnline(false);
     }
 
     switch (m_client->state()) {
@@ -267,36 +278,24 @@ void ClientWorker::logOut(bool isApplicationBeingClosed)
         if (isApplicationBeingClosed && m_registrationManager->registerOnConnectEnabled()) {
             m_client->disconnectFromServer();
         } else {
-            qCDebug(KAIDAN_LOG) << "[main] Tried to disconnect even if still connecting! Waiting for connecting to succeed and disconnect afterwards.";
+            qCDebug(KAIDAN_CORE_LOG) << "Tried to disconnect even if still connecting! Waiting for connecting to succeed and disconnect afterwards.";
             m_isDisconnecting = true;
         }
 
         break;
     case QXmppClient::ConnectedState:
-        if (AccountManager::instance()->hasNewCredentials()) {
-            AccountManager::instance()->setHasNewCredentials(false);
-        }
-
-        if (AccountManager::instance()->hasNewConnectionSettings()) {
-            AccountManager::instance()->setHasNewConnectionSettings(false);
-        }
-
-        await(
-            EncryptionController::instance(),
-            []() {
-                return EncryptionController::instance()->unload();
-            },
-            this,
-            [this]() {
+        runOnThread(EncryptionController::instance(), [this]() {
+            EncryptionController::instance()->unload().then(this, [this]() {
                 m_client->disconnectFromServer();
             });
+        });
     }
 }
 
 void ClientWorker::onConnected()
 {
     // no mutex needed, because this is called from updateClient()
-    qCDebug(KAIDAN_LOG) << "[client] Connected successfully to server";
+    qCDebug(KAIDAN_CORE_LOG) << "Connected to server";
 
     // If there was an error before, notify about its absence.
     Q_EMIT connectionErrorChanged(ClientWorker::NoError);
@@ -327,31 +326,31 @@ void ClientWorker::onConnected()
 
             // The following tasks are only done after a login with new credentials or connection
             // settings.
-            if (AccountManager::instance()->hasNewCredentials() || AccountManager::instance()->hasNewConnectionSettings()) {
-                if (AccountManager::instance()->hasNewCredentials()) {
-                    Q_EMIT loggedInWithNewCredentials();
-                }
+            if (AccountManager::instance()->hasNewAccount()) {
+                Q_EMIT loggedInWithNewCredentials();
 
                 // Store the valid connection data.
-                AccountManager::instance()->storeConnectionData();
+                AccountManager::instance()->storeAccount();
             }
 
             // Enable auto reconnection so that the client is always trying to reconnect
             // automatically in case of a connection outage.
             m_client->configuration().setAutoReconnectionEnabled(true);
 
+            const auto jid = AccountManager::instance()->account().jid;
+
             // Send message that could not be sent yet because the client was offline.
-            runOnThread(MessageController::instance(), [jid = AccountManager::instance()->jid()]() {
+            runOnThread(MessageController::instance(), [jid]() {
                 MessageController::instance()->sendPendingMessages();
             });
 
             // Send read markers that could not be sent yet because the client was offline.
-            runOnThread(RosterModel::instance(), [jid = AccountManager::instance()->jid()]() {
+            runOnThread(RosterModel::instance(), [jid]() {
                 RosterModel::instance()->sendPendingReadMarkers(jid);
             });
 
             // Send message reactions that could not be sent yet because the client was offline.
-            runOnThread(MessageController::instance(), [jid = AccountManager::instance()->jid()]() {
+            runOnThread(MessageController::instance(), [jid]() {
                 MessageController::instance()->sendPendingMessageReactions(jid);
             });
 
@@ -363,7 +362,7 @@ void ClientWorker::onConnected()
 
 void ClientWorker::onDisconnected()
 {
-    qCDebug(KAIDAN_LOG) << "[client] Disconnected";
+    qCDebug(KAIDAN_CORE_LOG) << "Disconnected from server";
 
     if (m_isReconnecting) {
         m_isReconnecting = false;
@@ -385,7 +384,7 @@ void ClientWorker::onConnectionStateChanged(QXmppClient::State connectionState)
 void ClientWorker::onConnectionError(const QXmppError &error)
 {
     // no mutex needed, because this is called from updateClient()
-    qCDebug(KAIDAN_LOG) << "[client] Connection error:" << error.description;
+    qCDebug(KAIDAN_CORE_LOG) << "Connection error:" << error.description;
 
     if (const auto socketError = error.value<QAbstractSocket::SocketError>()) {
         switch (*socketError) {
@@ -448,7 +447,7 @@ bool ClientWorker::startPendingTasks()
         isBusy = true;
     }
 
-    return !AccountManager::instance()->hasNewCredentials() && isBusy;
+    return !AccountManager::instance()->hasNewAccount() && isBusy;
 }
 
 #include "moc_ClientWorker.cpp"
