@@ -4,6 +4,7 @@
 
 #include "EncryptionController.h"
 
+// Kaidan
 #include "OmemoController.h"
 
 EncryptionController *EncryptionController::s_instance = nullptr;
@@ -84,7 +85,7 @@ void EncryptionController::removeContactDevices(const QString &jid)
 
 QFuture<void> EncryptionController::unload()
 {
-    return m_omemoController->unsubscribeFromDeviceLists();
+    return m_omemoController->unload();
 }
 
 QFuture<void> EncryptionController::reset()
