@@ -4,11 +4,12 @@
 
 #pragma once
 
+// Qt
 #include <QFuture>
 #include <QHash>
 #include <QList>
 #include <QObject>
-
+// QXmpp
 #include <QXmppTrustLevel.h>
 
 class OmemoController;
@@ -40,8 +41,8 @@ public:
 
     static EncryptionController *instance();
 
-    EncryptionController(QObject *parent = nullptr);
-    ~EncryptionController();
+    explicit EncryptionController(QObject *parent = nullptr);
+    ~EncryptionController() override;
 
     QFuture<void> load();
     QFuture<void> setUp();
