@@ -4,7 +4,8 @@
 
 #include "FileModel.h"
 
-#include "FutureUtils.h"
+// Kaidan
+#include "KaidanCoreLog.h"
 #include "MediaUtils.h"
 #include "MessageDb.h"
 
@@ -53,28 +54,27 @@ QVariant FileModel::data(const QModelIndex &index, int role) const
 
             auto fileModel = const_cast<FileModel *>(this);
 
-            await(MediaUtils::generateThumbnail(url, file.mimeTypeName(), VIDEO_THUMBNAIL_EDGE_PIXEL_COUNT),
-                  fileModel,
-                  [fileModel, pIndex = QPersistentModelIndex(index), fileId = file.fileId()](const QByteArray &thumbnail) mutable {
-                      if (!pIndex.isValid()) {
-                          return;
-                      }
+            MediaUtils::generateThumbnail(url, file.mimeTypeName(), VIDEO_THUMBNAIL_EDGE_PIXEL_COUNT)
+                .then(fileModel, [fileModel, pIndex = QPersistentModelIndex(index), fileId = file.fileId()](const QByteArray &thumbnail) mutable {
+                    if (!pIndex.isValid()) {
+                        return;
+                    }
 
-                      auto &file = fileModel->m_files[pIndex.row()];
+                    auto &file = fileModel->m_files[pIndex.row()];
 
-                      if (file.fileId() != fileId) {
-                          return;
-                      }
+                    if (file.fileId() != fileId) {
+                        return;
+                    }
 
-                      file.thumbnail = thumbnail;
+                    file.thumbnail = thumbnail;
 
-                      Q_EMIT fileModel->dataChanged(pIndex,
-                                                    pIndex,
-                                                    {
-                                                        static_cast<int>(Role::File),
-                                                        static_cast<int>(Role::Thumbnail),
-                                                    });
-                  });
+                    Q_EMIT fileModel->dataChanged(pIndex,
+                                                  pIndex,
+                                                  {
+                                                      static_cast<int>(Role::File),
+                                                      static_cast<int>(Role::Thumbnail),
+                                                  });
+                });
         }
         }
     }
@@ -137,13 +137,12 @@ void FileModel::setFiles(const Files &files)
     }
 }
 
-#ifndef BUILD_TESTS
 void FileModel::loadFiles()
 {
     m_watcher.cancel();
 
     if (m_accountJid.isEmpty()) {
-        qWarning("FileModel: Trying to call loadFiles() but m_accountJid is empty.");
+        qCWarning(KAIDAN_CORE_LOG, "FileModel: Trying to call loadFiles() but m_accountJid is empty.");
     } else if (m_chatJid.isEmpty()) {
         m_watcher.setFuture(MessageDb::instance()->fetchFiles(m_accountJid));
     } else {
@@ -156,15 +155,14 @@ void FileModel::loadDownloadedFiles()
     m_watcher.cancel();
 
     if (m_accountJid.isEmpty()) {
-        qWarning(
-            "FileModel: Trying to call loadDownloadedFiles() but m_accountJid is "
-            "empty.");
+        qCWarning(KAIDAN_CORE_LOG,
+                  "FileModel: Trying to call loadDownloadedFiles() but m_accountJid is "
+                  "empty.");
     } else if (m_chatJid.isEmpty()) {
         m_watcher.setFuture(MessageDb::instance()->fetchDownloadedFiles(m_accountJid));
     } else {
         m_watcher.setFuture(MessageDb::instance()->fetchDownloadedFiles(m_accountJid, m_chatJid));
     }
 }
-#endif
 
 #include "moc_FileModel.cpp"
