@@ -5,18 +5,18 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "FileSharingController.h"
-#include "kaidan_debug.h"
 
 // std
 #include <array>
-
+// Qt
 #include <QDir>
-#include <QFile>
 #include <QImage>
 #include <QMimeDatabase>
 #include <QStandardPaths>
 #include <QStringBuilder>
-
+// KDE
+#include <KFileUtils>
+// QXmpp
 #include <QXmppBitsOfBinaryDataList.h>
 #include <QXmppEncryptedFileSharingProvider.h>
 #include <QXmppError.h>
@@ -29,18 +29,17 @@
 #include <QXmppPromise.h>
 #include <QXmppUploadRequestManager.h>
 #include <QXmppUtils.h>
-
-#include <KFileUtils>
-
+// Kaidan
 #include "Account.h"
 #include "AccountDb.h"
 #include "Algorithms.h"
 #include "FileProgressCache.h"
 #include "FutureUtils.h"
-#include "Globals.h"
 #include "Kaidan.h"
+#include "KaidanCoreLog.h"
 #include "MessageDb.h"
 #include "ServerFeaturesCache.h"
+#include "SystemUtils.h"
 
 template<typename T, typename Lambda>
 auto find_if(T &container, Lambda lambda)
@@ -197,7 +196,7 @@ auto FileSharingController::sendFiles(QList<File> files, bool encrypt) -> QXmppT
         return sendFile(file, encrypt);
     });
 
-    await(join(this, std::move(futures)), this, [promise = std::move(promise), files = std::move(files)](auto &&uploadResults) mutable {
+    join(this, std::move(futures)).then(this, [promise = std::move(promise), files = std::move(files)](QList<UploadResult> &&uploadResults) mutable {
         // Check if any of the uploads failed
         bool failed = std::any_of(uploadResults.begin(), uploadResults.end(), [](const auto &result) {
             auto &[id, uploadResult] = result;
@@ -309,7 +308,7 @@ void FileSharingController::downloadFile(const QString &messageId, const File &f
     auto *client = Kaidan::instance()->client();
 
     runOnThread(client, [this, client, messageId, fileId = file.id, fileShare = file.toQXmpp()] {
-        QString dirPath = QStandardPaths::writableLocation(QStandardPaths::DownloadLocation) + QDir::separator() + QStringLiteral(APPLICATION_DISPLAY_NAME);
+        QString dirPath = SystemUtils::downloadDirectory();
 
         if (auto dir = QDir(dirPath); !dir.exists()) {
             dir.mkpath(QStringLiteral("."));
@@ -319,7 +318,7 @@ void FileSharingController::downloadFile(const QString &messageId, const File &f
         auto maybeFileName = andThen(fileShare.metadata().filename(), sanitizeFilename);
 
         // Add fallback file name, so we always have a file name
-        auto filename = [&]() {
+        auto fileName = [&]() {
             if (maybeFileName) {
                 return maybeFileName->first;
             }
@@ -337,23 +336,17 @@ void FileSharingController::downloadFile(const QString &messageId, const File &f
             return QString();
         }();
 
-        auto makeFileName = [&]() -> QString {
-            return dirPath % QDir::separator() % filename % QLatin1Char('.') % fileExtension;
-        };
+        const QString fileNameWithExtension = fileName + QLatin1Char('.') + fileExtension;
 
-        QString filePath = makeFileName();
-
-        // Check if the file name is already taken, and propose one that is unique
-        if (QFile::exists(filePath)) {
-            filename = KFileUtils::suggestName(QUrl::fromLocalFile(dirPath), filename);
-            filePath = makeFileName();
-        }
+        // Ensure that the file name is locally unique.
+        const auto uniqueFileNameWithExtension = KFileUtils::suggestName(QUrl::fromLocalFile(dirPath), fileNameWithExtension);
+        const QString filePath = dirPath + QDir::separator() + uniqueFileNameWithExtension;
 
         // Open the file at the resulting path
         auto output = std::make_unique<QFile>(filePath);
 
         if (!output->open(QIODevice::WriteOnly)) {
-            qCDebug(KAIDAN_LOG) << "Failed to open output file at" << filePath;
+            qCDebug(KAIDAN_CORE_LOG) << "Failed to open output file at" << filePath;
             return;
         }
 
@@ -372,8 +365,8 @@ void FileSharingController::downloadFile(const QString &messageId, const File &f
             if (std::holds_alternative<QXmppError>(result)) {
                 auto errorText = std::get<QXmppError>(result).description;
 
-                qCDebug(KAIDAN_LOG) << "[FileSharingController] Couldn't download file:" << errorText;
-                Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Couldn't download file: %1").arg(errorText));
+                qCDebug(KAIDAN_CORE_LOG) << "Could not download file:" << errorText;
+                Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Could not download file: %1").arg(errorText));
             } else if (std::holds_alternative<QXmppFileDownload::Downloaded>(result)) {
                 MessageDb::instance()->updateMessage(messageId, [=](Message &message) {
                     auto file = find_if(message.files, [=](const auto &file) {
@@ -407,9 +400,7 @@ void FileSharingController::deleteFile(const QString &messageId, const File &fil
     });
 
     // don't delete files not downloaded by us
-    const auto downloadsFolder =
-        QStandardPaths::writableLocation(QStandardPaths::DownloadLocation) + QDir::separator() + QStringLiteral(APPLICATION_DISPLAY_NAME);
-    if (file.localFilePath.startsWith(downloadsFolder)) {
+    if (file.localFilePath.startsWith(SystemUtils::downloadDirectory())) {
         QFile::remove(file.localFilePath);
     }
 }
