@@ -4,6 +4,7 @@
 
 #pragma once
 
+// Qt
 #include <QObject>
 
 struct GroupChatUser;
@@ -32,7 +33,7 @@ public:
     static GroupChatController *instance();
 
     explicit GroupChatController(QObject *parent = nullptr);
-    ~GroupChatController();
+    ~GroupChatController() override;
 
     bool busy();
     Q_SIGNAL void busyChanged();
