@@ -4,9 +4,9 @@
 
 #include "GroupChatUserKeyAuthenticationFilterModel.h"
 
+// Kaidan
 #include "Algorithms.h"
 #include "EncryptionController.h"
-#include "FutureUtils.h"
 #include "GroupChatUserModel.h"
 
 GroupChatUserKeyAuthenticationFilterModel::GroupChatUserKeyAuthenticationFilterModel(QObject *parent)
@@ -63,7 +63,7 @@ void GroupChatUserKeyAuthenticationFilterModel::updateJids()
         return;
     }
 
-    await(EncryptionController::instance()->devices(model->accountJid(), model->userJids()), this, [this](QList<EncryptionController::Device> &&devices) {
+    EncryptionController::instance()->devices(model->accountJid(), model->userJids()).then(this, [this](QList<EncryptionController::Device> &&devices) {
         const auto jids = transformFilter<QList<QString>>(std::as_const(devices), [](const EncryptionController::Device &device) -> std::optional<QString> {
             if (TRUST_LEVEL_AUTHENTICATABLE.testFlag(device.trustLevel)) {
                 return device.jid;
