@@ -4,6 +4,7 @@
 
 #pragma once
 
+// Qt
 #include <QSortFilterProxyModel>
 
 class GroupChatUserKeyAuthenticationFilterModel : public QSortFilterProxyModel
@@ -11,7 +12,7 @@ class GroupChatUserKeyAuthenticationFilterModel : public QSortFilterProxyModel
     Q_OBJECT
 
 public:
-    GroupChatUserKeyAuthenticationFilterModel(QObject *parent = nullptr);
+    explicit GroupChatUserKeyAuthenticationFilterModel(QObject *parent = nullptr);
 
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 
