@@ -4,10 +4,11 @@
 
 #include "GroupChatUserModel.h"
 
+// Kaidan
 #include "Algorithms.h"
-#include "FutureUtils.h"
 #include "Globals.h"
 #include "GroupChatUserDb.h"
+#include "KaidanCoreLog.h"
 #include "RosterModel.h"
 
 GroupChatUserModel::GroupChatUserModel(QObject *parent)
@@ -34,7 +35,7 @@ QHash<int, QByteArray> GroupChatUserModel::roleNames() const
 QVariant GroupChatUserModel::data(const QModelIndex &index, int role) const
 {
     if (!hasIndex(index.row(), index.column(), index.parent())) {
-        qWarning() << "Could not get data from GroupChatUserModel." << index << role;
+        qCWarning(KAIDAN_CORE_LOG) << "Could not get data from GroupChatUserModel." << index << role;
         return {};
     }
 
@@ -133,7 +134,7 @@ QString GroupChatUserModel::participantName(const QString &accountJid, const QSt
 
 void GroupChatUserModel::fetchUsers()
 {
-    await(GroupChatUserDb::instance()->users(m_accountJid, m_chatJid, m_users.size()), this, [this](QList<GroupChatUser> &&users) {
+    GroupChatUserDb::instance()->users(m_accountJid, m_chatJid, m_users.size()).then(this, [this](QList<GroupChatUser> &&users) {
         for (const auto &user : std::as_const(users)) {
             addUser(user);
         }
