@@ -15,6 +15,8 @@
 
 #pragma once
 
+// Qt
+#include <QStringList>
 // Kaidan
 #include "AccountMigrationManager.h"
 #include "ClientWorker.h"
@@ -94,7 +96,7 @@ public:
      */
     Kaidan(bool enableLogging = true, QObject *parent = nullptr);
 
-    ~Kaidan();
+    ~Kaidan() override;
 
     /**
      * Connects to the XMPP server and logs in to it.
@@ -373,10 +375,12 @@ public:
     /**
      * Receives messages from another instance of the application
      */
-    Q_INVOKABLE void receiveMessage(quint32, const QByteArray &msg)
+    Q_INVOKABLE void receiveMessage(const QStringList &arguments, const QString &workingDirectory)
     {
-        // currently we only send XMPP URIs
-        addOpenUri(QString::fromUtf8(msg));
+        Q_UNUSED(workingDirectory)
+        for (const QString &arg : arguments) {
+            addOpenUri(arg);
+        }
     }
 
 private:
