@@ -6,7 +6,6 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "MediaUtils.h"
-#include "kaidan_debug.h"
 
 // Qt
 #include <QBuffer>
@@ -27,6 +26,7 @@
 #include <KIO/PreviewJob>
 // Kaidan
 #include "FutureUtils.h"
+#include "KaidanCoreLog.h"
 #include "SystemUtils.h"
 
 const auto IMAGE_FILE_EXTENSION = QStringLiteral("jpg");
@@ -611,7 +611,7 @@ QFuture<QByteArray> MediaUtils::generateThumbnail(const QUrl &localFileUrl, cons
     });
 
     QObject::connect(job, &KIO::PreviewJob::failed, [interface](const KFileItem &item) mutable {
-        qCDebug(KAIDAN_LOG) << "Could not generate a thumbnail for" << item.url();
+        qCDebug(KAIDAN_CORE_LOG) << "Could not generate a thumbnail for" << item.url();
         reportFinishedResult(interface, {});
     });
 
