@@ -189,12 +189,8 @@ struct GroupChatInvitation {
 
 Q_DECLARE_METATYPE(GroupChatInvitation)
 
-/**
- * @brief This class is used to load messages from the database and use them in
- * the @c MessageModel. The class inherits from @c QXmppMessage and most
- * properties are shared.
- */
-struct Message {
+class Message
+{
     Q_GADGET
     Q_DECLARE_TR_FUNCTIONS(Message)
 
@@ -239,7 +235,6 @@ public:
     QString replaceId;
     std::optional<Reply> reply;
     QDateTime timestamp;
-    QString body;
     // End-to-end encryption used for this message.
     Encryption::Enum encryption = Encryption::NoEncryption;
     // ID of this message's sender's public long-term end-to-end encryption key.
@@ -271,6 +266,10 @@ public:
     bool isServerMessage() const;
     bool isGroupChatMessage() const;
 
+    QString body() const;
+    void setPreparedBody(const QString &preparedBody);
+    void setUnpreparedBody(const QString &unpreparedBody);
+
     // Text to be shown for the user depending on the message's content
     QString text() const;
 
@@ -287,6 +286,8 @@ private:
     bool fileFallbackIncludedInMainMessage() const;
     static bool addFileFallbackMessageBase(QXmppMessage &message, const File &file);
     QString groupChatInvitationText() const;
+
+    QString m_body;
 };
 
 Q_DECLARE_METATYPE(Message)
