@@ -7,6 +7,16 @@
 
 #include "MessageComposition.h"
 
+// Qt
+#include <QFileDialog>
+#include <QFutureWatcher>
+#include <QGuiApplication>
+#include <QMimeDatabase>
+// KDE
+#include <KFileItem>
+#include <KIO/PreviewJob>
+// QXmpp
+#include <QXmppUtils.h>
 // Kaidan
 #include "Algorithms.h"
 #include "ChatController.h"
@@ -19,16 +29,6 @@
 #include "MessageDb.h"
 #include "RosterModel.h"
 #include "ServerFeaturesCache.h"
-// Qt
-#include <QFileDialog>
-#include <QFutureWatcher>
-#include <QGuiApplication>
-#include <QMimeDatabase>
-// QXmpp
-#include <QXmppUtils.h>
-// KF
-#include <KFileItem>
-#include <KIO/PreviewJob>
 
 MessageComposition::MessageComposition()
     : m_fileSelectionModel(new FileSelectionModel(this))
@@ -186,7 +186,7 @@ void MessageComposition::send()
     message.originId = originId;
     setReply(message, m_replyToJid, m_replyToGroupChatParticipantId, m_replyId, m_replyQuote);
     message.timestamp = QDateTime::currentDateTimeUtc();
-    message.body = m_body;
+    message.setUnpreparedBody(m_body);
     message.encryption = ChatController::instance()->activeEncryption();
     message.deliveryState = DeliveryState::Pending;
     message.isSpoiler = m_isSpoiler;
@@ -262,7 +262,7 @@ void MessageComposition::correct()
          body = m_body,
          spoilerHint = m_spoilerHint](Message &message) {
             setReply(message, replyToJid, replyToGroupChatParticipantId, replyId, replyQuote);
-            message.body = body;
+            message.setUnpreparedBody(body);
             message.isSpoiler = !spoilerHint.isEmpty();
             message.spoilerHint = spoilerHint;
 
@@ -283,7 +283,7 @@ void MessageComposition::correct()
                         // this way they can tell which version of the message is the latest
                         message.timestamp = QDateTime::currentDateTimeUtc();
 
-                        await(MessageController::instance()->send(message.toQXmpp()), this, [messageId = message.id](QXmpp::SendResult &&result) {
+                        MessageController::instance()->send(message.toQXmpp()).then(this, [messageId = message.id](QXmpp::SendResult &&result) {
                             if (std::holds_alternative<QXmppError>(result)) {
                                 // TODO store in the database only error codes, assign text messages right in the QML
                                 Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Message correction was not successful"));
@@ -351,18 +351,18 @@ void MessageComposition::loadDraft()
     }
 
     auto future = MessageDb::instance()->fetchDraftMessage(m_accountJid, m_chatJid);
-    await(future, this, [this](std::optional<Message> &&message) {
+    future.then(this, [this](std::optional<Message> &&message) {
         if (message) {
             if (const auto replaceId = message->replaceId; !replaceId.isEmpty()) {
                 setReplaceId(replaceId);
 
-                await(MessageDb::instance()->fetchMessage(m_accountJid, m_chatJid, replaceId), this, [this](std::optional<Message> &&message) {
+                MessageDb::instance()->fetchMessage(m_accountJid, m_chatJid, replaceId).then(this, [this](std::optional<Message> &&message) {
                     if (message) {
                         if (const auto &reply = message->reply) {
-                            setOriginalReplyId(message->reply->id);
+                            setOriginalReplyId(reply->id);
                         }
 
-                        setOriginalBody(message->body);
+                        setOriginalBody(message->body());
 
                         Q_EMIT isDraftChanged();
                     }
@@ -376,12 +376,12 @@ void MessageComposition::loadDraft()
                 // Only process if it is not a reply to an own message.
                 if (!(m_replyToJid.isEmpty() && m_replyToGroupChatParticipantId.isEmpty())) {
                     if (const auto rosterItem = RosterModel::instance()->findItem(m_chatJid); rosterItem->isGroupChat()) {
-                        await(GroupChatUserDb::instance()->user(m_accountJid, m_chatJid, m_replyToGroupChatParticipantId),
-                              this,
-                              [this](const std::optional<GroupChatUser> &user) {
-                                  setReplyToName(user ? user->displayName() : m_replyToGroupChatParticipantId);
-                                  Q_EMIT isDraftChanged();
-                              });
+                        GroupChatUserDb::instance()
+                            ->user(m_accountJid, m_chatJid, m_replyToGroupChatParticipantId)
+                            .then(this, [this](const std::optional<GroupChatUser> &user) {
+                                setReplyToName(user ? user->displayName() : m_replyToGroupChatParticipantId);
+                                Q_EMIT isDraftChanged();
+                            });
                     } else {
                         setReplyToName(rosterItem->displayName());
                     }
@@ -391,7 +391,7 @@ void MessageComposition::loadDraft()
                 setReplyQuote(reply->quote);
             }
 
-            setBody(message->body);
+            setBody(message->body());
             setSpoiler(message->isSpoiler);
             setSpoilerHint(message->spoilerHint);
             setIsDraft(true);
@@ -423,7 +423,7 @@ void MessageComposition::saveDraft()
                                                           message.replaceId = replaceId;
                                                           setReply(message, replyToJid, replyToGroupChatParticipantId, replyId, replyQuote);
                                                           message.timestamp = QDateTime::currentDateTimeUtc();
-                                                          message.body = body;
+                                                          message.setUnpreparedBody(body);
                                                           message.isSpoiler = isSpoiler;
                                                           message.spoilerHint = spoilerHint;
                                                       });
@@ -437,7 +437,7 @@ void MessageComposition::saveDraft()
         message.replaceId = m_replaceId;
         setReply(message, m_replyToJid, m_replyToGroupChatParticipantId, m_replyId, m_replyQuote);
         message.timestamp = QDateTime::currentDateTimeUtc();
-        message.body = m_body;
+        message.setUnpreparedBody(m_body);
         message.isSpoiler = m_isSpoiler;
         message.spoilerHint = m_spoilerHint;
         message.deliveryState = DeliveryState::Draft;
@@ -554,12 +554,11 @@ void FileSelectionModel::addFile(const QUrl &localFileUrl, bool isNew)
     };
 
     if (file.type() == MessageType::MessageVideo) {
-        await(MediaUtils::generateThumbnail(file.localFileUrl(), file.mimeTypeName(), VIDEO_THUMBNAIL_EDGE_PIXEL_COUNT),
-              this,
-              [file, insertFile](const QByteArray &thumbnail) mutable {
-                  file.thumbnail = thumbnail;
-                  insertFile(std::move(file));
-              });
+        MediaUtils::generateThumbnail(file.localFileUrl(), file.mimeTypeName(), VIDEO_THUMBNAIL_EDGE_PIXEL_COUNT)
+            .then(this, [file, insertFile](const QByteArray &thumbnail) mutable {
+                file.thumbnail = thumbnail;
+                insertFile(std::move(file));
+            });
     } else {
         insertFile(std::move(file));
     }
