@@ -8,8 +8,9 @@
 
 #pragma once
 
+// Qt
 #include <QObject>
-
+// Kaidan
 #include "DatabaseComponent.h"
 #include "Message.h"
 #include "SqlUtils.h"
@@ -37,7 +38,7 @@ public:
     };
 
     explicit MessageDb(Database *db, QObject *parent = nullptr);
-    ~MessageDb();
+    ~MessageDb() override;
 
     static MessageDb *instance();
 
