@@ -4,10 +4,10 @@
 
 #include "MessageReactionModel.h"
 
+// Kaidan
 #include "GroupChatUser.h"
 #include "GroupChatUserDb.h"
-// #include "MessageDb.h"
-// #include "RosterModel.h"
+#include "KaidanCoreLog.h"
 
 MessageReactionModel::MessageReactionModel(QObject *parent)
     : QAbstractListModel(parent)
@@ -33,7 +33,7 @@ QVariant MessageReactionModel::data(const QModelIndex &index, int role) const
     const auto row = index.row();
 
     if (!hasIndex(row, index.column(), index.parent())) {
-        qWarning() << "Could not get data from MessageReactionModel." << index << role;
+        qCWarning(KAIDAN_CORE_LOG) << "Could not get data from MessageReactionModel." << index << role;
         return {};
     }
 
@@ -57,7 +57,7 @@ void MessageReactionModel::setReactions(const QList<DetailedMessageReaction> &re
         this->reactions = reactions;
 
         for (auto &reaction : this->reactions) {
-            await(GroupChatUserDb::instance()->user(accountJid, chatJid, reaction.senderId), this, [this, &reaction](const std::optional<GroupChatUser> user) {
+            GroupChatUserDb::instance()->user(accountJid, chatJid, reaction.senderId).then(this, [this, &reaction](const std::optional<GroupChatUser> user) {
                 if (user) {
                     beginResetModel();
                     reaction.senderJid = user->jid;
