@@ -4,8 +4,10 @@
 
 #pragma once
 
-#include "MessageModel.h"
+// Qt
 #include <QAbstractListModel>
+// Kaidan
+#include "MessageModel.h"
 
 class MessageReactionModel : public QAbstractListModel
 {
@@ -22,7 +24,7 @@ public:
     };
 
     explicit MessageReactionModel(QObject *parent = nullptr);
-    ~MessageReactionModel() = default;
+    ~MessageReactionModel() override = default;
 
     [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
