@@ -4,8 +4,6 @@
 
 #include "MixController.h"
 
-// Qt
-#include <QStringBuilder>
 // QXmpp
 #include "QXmppMixParticipantItem.h"
 #include <QXmppClient.h>
@@ -252,7 +250,7 @@ void MixController::inviteContactToChannel(const QString &channelJid, const QStr
     message.id = QXmppUtils::generateStanzaUuid();
     message.originId = message.id;
     message.timestamp = QDateTime::currentDateTimeUtc();
-    message.body = groupChatUri.toString();
+    message.setPreparedBody(groupChatUri.toString());
     message.encryption = ChatController::instance()->activeEncryption();
     message.deliveryState = DeliveryState::Pending;
     message.receiptRequested = true;
