@@ -6,15 +6,14 @@
 
 #include "OmemoController.h"
 
-#include <QStringBuilder>
+// Qt
 #include <QTimer>
-
+// QXmpp
 #include <QXmppOmemoManager.h>
-
+// Kaidan
 #include "AccountManager.h"
 #include "Algorithms.h"
 #include "FutureUtils.h"
-#include "Globals.h"
 #include "Kaidan.h"
 #include "PresenceCache.h"
 #include "RosterModel.h"
@@ -32,32 +31,32 @@ OmemoController::OmemoController(QObject *parent)
             &QXmppOmemoManager::trustLevelsChanged,
             this,
             [](const QMultiHash<QString, QByteArray> &modifiedKeys) {
-                Q_EMIT EncryptionController::instance()->keysChanged(AccountManager::instance()->jid(), modifiedKeys.keys());
+                Q_EMIT EncryptionController::instance()->keysChanged(AccountManager::instance()->account().jid, modifiedKeys.keys());
             });
 
     connect(Kaidan::instance()->client()->xmppClient()->findExtension<QXmppOmemoManager>(),
             &QXmppOmemoManager::deviceAdded,
             this,
             [](const QString &jid, uint32_t) {
-                Q_EMIT EncryptionController::instance()->devicesChanged(AccountManager::instance()->jid(), {jid});
+                Q_EMIT EncryptionController::instance()->devicesChanged(AccountManager::instance()->account().jid, {jid});
             });
 
     connect(Kaidan::instance()->client()->xmppClient()->findExtension<QXmppOmemoManager>(),
             &QXmppOmemoManager::deviceChanged,
             this,
             [](const QString &jid, uint32_t) {
-                Q_EMIT EncryptionController::instance()->devicesChanged(AccountManager::instance()->jid(), {jid});
+                Q_EMIT EncryptionController::instance()->devicesChanged(AccountManager::instance()->account().jid, {jid});
             });
 
     connect(Kaidan::instance()->client()->xmppClient()->findExtension<QXmppOmemoManager>(),
             &QXmppOmemoManager::deviceRemoved,
             this,
             [](const QString &jid, uint32_t) {
-                Q_EMIT EncryptionController::instance()->devicesChanged(AccountManager::instance()->jid(), {jid});
+                Q_EMIT EncryptionController::instance()->devicesChanged(AccountManager::instance()->account().jid, {jid});
             });
 
     connect(Kaidan::instance()->client()->xmppClient()->findExtension<QXmppOmemoManager>(), &QXmppOmemoManager::devicesRemoved, this, [](const QString &jid) {
-        Q_EMIT EncryptionController::instance()->devicesChanged(AccountManager::instance()->jid(), {jid});
+        Q_EMIT EncryptionController::instance()->devicesChanged(AccountManager::instance()->account().jid, {jid});
     });
 
     connect(Kaidan::instance()->client()->xmppClient()->findExtension<QXmppOmemoManager>(), &QXmppOmemoManager::allDevicesRemoved, this, [] {
@@ -114,6 +113,8 @@ QFuture<void> OmemoController::setUp()
             this,
             [this, interface](bool isSetUp) mutable {
                 if (isSetUp) {
+                    m_isLoaded = true;
+
                     // Enabling the session building for new devices is delayed after all (or at least
                     // most) devices are automatically received from the servers.
                     // That way, the sessions for those devices, which are only new during this setup,
@@ -133,6 +134,22 @@ QFuture<void> OmemoController::setUp()
     return interface.future();
 }
 
+QFuture<void> OmemoController::unload()
+{
+    QFutureInterface<void> interface(QFutureInterfaceBase::Started);
+
+    if (m_isLoaded) {
+        unsubscribeFromDeviceLists().then([this, interface]() mutable {
+            m_isLoaded = false;
+            interface.reportFinished();
+        });
+    } else {
+        interface.reportFinished();
+    }
+
+    return interface.future();
+}
+
 QFuture<void> OmemoController::initializeAccount(const QString &accountJid)
 {
     QFutureInterface<void> interface(QFutureInterfaceBase::Started);
@@ -174,7 +191,7 @@ QFuture<void> OmemoController::initializeChat(const QString &accountJid, const Q
         futures.append(subscribeToDeviceLists(deviceListSubscriptionJids));
     }
 
-    await(joinVoidFutures(this, std::move(futures)), this, [this, interface, accountJid, jids = jids]() mutable {
+    joinVoidFutures(this, std::move(futures)).then(this, [this, interface, accountJid, jids = jids]() mutable {
         jids.append(accountJid);
         buildMissingSessions(interface, jids);
     });
@@ -242,23 +259,6 @@ QFuture<void> OmemoController::subscribeToDeviceLists(const QList<QString> &jids
     return interface.future();
 }
 
-QFuture<void> OmemoController::unsubscribeFromDeviceLists()
-{
-    QFutureInterface<void> interface(QFutureInterfaceBase::Started);
-
-    callRemoteTask(
-        Kaidan::instance()->client(),
-        [this]() {
-            return std::pair{Kaidan::instance()->client()->xmppClient()->findExtension<QXmppOmemoManager>()->unsubscribeFromDeviceLists(), this};
-        },
-        this,
-        [interface](auto) mutable {
-            interface.reportFinished();
-        });
-
-    return interface.future();
-}
-
 QFuture<void> OmemoController::reset()
 {
     QFutureInterface<void> interface(QFutureInterfaceBase::Started);
@@ -401,4 +401,21 @@ void OmemoController::enableSessionBuildingForNewDevices()
     });
 }
 
+QFuture<void> OmemoController::unsubscribeFromDeviceLists()
+{
+    QFutureInterface<void> interface(QFutureInterfaceBase::Started);
+
+    callRemoteTask(
+        Kaidan::instance()->client(),
+        [this]() {
+            return std::pair{Kaidan::instance()->client()->xmppClient()->findExtension<QXmppOmemoManager>()->unsubscribeFromDeviceLists(), this};
+        },
+        this,
+        [interface](auto) mutable {
+            interface.reportFinished();
+        });
+
+    return interface.future();
+}
+
 #include "moc_OmemoController.cpp"
