@@ -5,11 +5,12 @@
 
 #pragma once
 
+// Qt
 #include <QFuture>
-
+// QXmpp
 #include <QXmppTask.h>
 #include <QXmppTrustLevel.h>
-
+// Kaidan
 #include "EncryptionController.h"
 
 class OmemoController : public QObject
@@ -21,6 +22,7 @@ public:
 
     QFuture<void> load();
     QFuture<void> setUp();
+    QFuture<void> unload();
     QFuture<void> reset();
     QFuture<void> resetLocally();
 
@@ -31,7 +33,6 @@ public:
 
     QFuture<void> requestDeviceLists(const QList<QString> &jids);
     QFuture<void> subscribeToDeviceLists(const QList<QString> &jids);
-    QFuture<void> unsubscribeFromDeviceLists();
 
     QFuture<QString> ownKey(const QString &accountJid);
     QFuture<QHash<QString, QHash<QString, QXmpp::TrustLevel>>> keys(const QString &accountJid, const QList<QString> &jids, QXmpp::TrustLevels trustLevels = {});
@@ -49,5 +50,7 @@ private:
      */
     void enableSessionBuildingForNewDevices();
 
+    QFuture<void> unsubscribeFromDeviceLists();
+
     bool m_isLoaded = false;
 };
