@@ -8,7 +8,6 @@
 
 // Qt
 #include <QClipboard>
-#include <QDebug>
 #include <QDesktopServices>
 #include <QDir>
 #include <QGeoCoordinate>
@@ -18,15 +17,13 @@
 #include <QMimeDatabase>
 #include <QRegularExpression>
 #include <QStandardPaths>
-#include <QStringBuilder>
 // QXmpp
-#ifndef BUILD_TESTS
-#include "qxmpp-exts/QXmppColorGenerator.h"
+#include <QXmppColorGeneration.h>
 #include <QXmppUri.h>
-#endif
 // Kaidan
 #include "AccountManager.h"
 #include "Globals.h"
+#include "KaidanCoreLog.h"
 #include "SystemUtils.h"
 
 const auto NEW_LINE = QStringLiteral("\n");
@@ -78,7 +75,6 @@ QString QmlUtils::systemCountryCode()
     return SystemUtils::systemLocaleCodes().countryCode;
 }
 
-#ifndef BUILD_TESTS
 QString QmlUtils::connectionErrorMessage(ClientWorker::ConnectionError error)
 {
     switch (error) {
@@ -111,7 +107,6 @@ QString QmlUtils::connectionErrorMessage(ClientWorker::ConnectionError error)
     }
     Q_UNREACHABLE();
 }
-#endif
 
 QString QmlUtils::getResourcePath(const QString &name)
 {
@@ -125,9 +120,6 @@ QString QmlUtils::getResourcePath(const QString &name)
     pathList << QCoreApplication::applicationDirPath() + QStringLiteral("/../share/") + QStringLiteral(APPLICATION_NAME);
     // get the standard app data locations for current platform
     pathList << QStandardPaths::standardLocations(QStandardPaths::AppDataLocation);
-#ifdef UBUNTU_TOUCH
-    pathList << QString("./share/") + QString(APPLICATION_NAME);
-#endif
 #ifndef NDEBUG
 #ifdef DEBUG_SOURCE_PATH
     // add source directory (only for debug builds)
@@ -147,7 +139,7 @@ QString QmlUtils::getResourcePath(const QString &name)
     }
 
     // no file found
-    qWarning() << "[main] Could NOT find media file:" << name;
+    qCWarning(KAIDAN_CORE_LOG) << "Could not find media file:" << name;
     return QString();
 }
 
@@ -197,7 +189,6 @@ QUrl QmlUtils::invitationUrl(const QString &uri)
     return QUrl(QStringLiteral(INVITATION_URL) + uri.mid(5));
 }
 
-#ifndef BUILD_TESTS
 QUrl QmlUtils::groupChatUri(const QString &groupChatJid)
 {
     QXmppUri uri;
@@ -205,7 +196,6 @@ QUrl QmlUtils::groupChatUri(const QString &groupChatJid)
     uri.setQuery(QXmpp::Uri::Join());
     return QUrl(uri.toString());
 }
-#endif
 
 bool QmlUtils::validateEncryptionKeyId(const QString &keyId)
 {
@@ -262,14 +252,7 @@ QString QmlUtils::formattedDataSize(qint64 fileSize)
 
 QColor QmlUtils::userColor(const QString &id, const QString &name)
 {
-#ifndef BUILD_TESTS
-    QXmppColorGenerator::RGBColor rgbColor = QXmppColorGenerator::generateColor(id.isEmpty() ? name : id);
-    return {rgbColor.red, rgbColor.green, rgbColor.blue};
-#else
-    Q_UNUSED(id)
-    Q_UNUSED(name)
-    return QColor(Qt::black);
-#endif
+    return QXmppColorGeneration::generateColor(id.isEmpty() ? name : id);
 }
 
 QString QmlUtils::chatStateDescription(const QString &displayName, const QXmppMessage::State state)
