@@ -5,6 +5,7 @@
 
 #pragma once
 
+// Kaidan
 #include "DatabaseComponent.h"
 
 struct RosterItem;
@@ -15,7 +16,7 @@ class RosterDb : public DatabaseComponent
 
 public:
     RosterDb(Database *db, QObject *parent = nullptr);
-    ~RosterDb();
+    ~RosterDb() override;
 
     static RosterDb *instance();
 
