@@ -12,17 +12,16 @@
 #include <QXmppRosterManager.h>
 #include <QXmppTask.h>
 // Kaidan
+#include "AccountManager.h"
 #include "AvatarFileStorage.h"
 #include "ChatHintModel.h"
 #include "EncryptionController.h"
 #include "GroupChatController.h"
-#include "Kaidan.h"
+#include "KaidanCoreLog.h"
 #include "MessageDb.h"
 #include "RosterDb.h"
 #include "RosterModel.h"
-#include "Settings.h"
 #include "VCardManager.h"
-#include "kaidan_debug.h"
 
 RosterManager::RosterManager(ClientWorker *clientWorker, QXmppClient *client, QObject *parent)
     : QObject(parent)
@@ -36,7 +35,7 @@ RosterManager::RosterManager(ClientWorker *clientWorker, QXmppClient *client, QO
 
     connect(m_manager, &QXmppRosterManager::itemAdded, this, [this](const QString &jid) {
         RosterItem rosterItem{m_client->configuration().jidBare(), m_manager->getRosterEntry(jid)};
-        rosterItem.encryption = Kaidan::instance()->settings()->encryption();
+        rosterItem.encryption = AccountManager::instance()->account().encryption;
         rosterItem.automaticMediaDownloadsRule = RosterItem::AutomaticMediaDownloadsRule::Default;
         rosterItem.lastMessageDateTime = QDateTime::currentDateTimeUtc();
         RosterDb::instance()->addItem(rosterItem);
@@ -102,7 +101,7 @@ RosterManager::RosterManager(ClientWorker *clientWorker, QXmppClient *client, QO
 
 void RosterManager::populateRoster()
 {
-    qCDebug(KAIDAN_LOG) << "[client] [RosterManager] Populating roster";
+    qCDebug(KAIDAN_CORE_LOG) << "Populating roster";
 
     // create a new list of contacts
     QHash<QString, RosterItem> items;
@@ -110,7 +109,7 @@ void RosterManager::populateRoster()
 
     for (const auto &jid : bareJids) {
         RosterItem rosterItem{m_client->configuration().jidBare(), m_manager->getRosterEntry(jid)};
-        rosterItem.encryption = Kaidan::instance()->settings()->encryption();
+        rosterItem.encryption = AccountManager::instance()->account().encryption;
         rosterItem.automaticMediaDownloadsRule = RosterItem::AutomaticMediaDownloadsRule::Default;
         items.insert(jid, rosterItem);
 
@@ -197,9 +196,8 @@ void RosterManager::addContact(const QString &jid, const QString &name, const QS
                 });
         }
     } else {
-        Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Could not add contact, as a result of not being connected."));
-        qWarning() << "[client] [RosterManager] Could not add contact, as a result of "
-                      "not being connected.";
+        Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Could not add contact as a result of not being connected."));
+        qCWarning(KAIDAN_CORE_LOG) << "Could not add contact as a result of not being connected.";
     }
 }
 
@@ -208,9 +206,8 @@ void RosterManager::removeContact(const QString &jid)
     if (m_client->state() == QXmppClient::ConnectedState) {
         m_manager->removeItem(jid);
     } else {
-        Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Could not remove contact, as a result of not being connected."));
-        qWarning() << "[client] [RosterManager] Could not remove contact, as a result of "
-                      "not being connected.";
+        Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Could not remove contact as a result of not being connected."));
+        qCWarning(KAIDAN_CORE_LOG) << "Could not remove contact as a result of not being connected.";
     }
 }
 
@@ -219,9 +216,8 @@ void RosterManager::renameContact(const QString &jid, const QString &newContactN
     if (m_client->state() == QXmppClient::ConnectedState) {
         m_manager->renameItem(jid, newContactName);
     } else {
-        Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Could not rename contact, as a result of not being connected."));
-        qWarning() << "[client] [RosterManager] Could not rename contact, as a result of "
-                      "not being connected.";
+        Q_EMIT Kaidan::instance()->passiveNotificationRequested(tr("Could not rename contact as a result of not being connected."));
+        qCWarning(KAIDAN_CORE_LOG) << "Could not rename contact as a result of not being connected.";
     }
 }
 
