@@ -16,8 +16,7 @@
 // Kaidan
 #include "AccountManager.h"
 #include "ChatController.h"
-#include "FutureUtils.h"
-#include "Kaidan.h"
+#include "KaidanCoreLog.h"
 #include "MessageController.h"
 #include "MessageDb.h"
 #include "RosterDb.h"
@@ -49,12 +48,12 @@ RosterModel::RosterModel(QObject *parent)
     connect(MessageDb::instance(), &MessageDb::draftMessageRemoved, this, &RosterModel::handleDraftMessageRemoved);
     connect(MessageDb::instance(), &MessageDb::messageRemoved, this, &RosterModel::handleMessageRemoved);
 
-    connect(AccountManager::instance(), &AccountManager::jidChanged, this, [this] {
+    connect(Kaidan::instance(), &Kaidan::openChatViewRequested, this, [this] {
         beginResetModel();
         m_items.clear();
         endResetModel();
 
-        await(RosterDb::instance()->fetchItems(), this, [this](const QList<RosterItem> &items) {
+        RosterDb::instance()->fetchItems().then(this, [this](const QList<RosterItem> &items) {
             handleItemsFetched(items);
         });
     });
@@ -97,7 +96,7 @@ QHash<int, QByteArray> RosterModel::roleNames() const
 QVariant RosterModel::data(const QModelIndex &index, int role) const
 {
     if (!hasIndex(index.row(), index.column(), index.parent())) {
-        qWarning() << "Could not get data from roster model." << index << role;
+        qCWarning(KAIDAN_CORE_LOG) << "Could not get data from roster model." << index << role;
         return {};
     }
 
@@ -568,7 +567,9 @@ void RosterModel::removeItems(const QString &accountJid)
 
 void RosterModel::handleAccountChanged()
 {
-    Q_EMIT dataChanged(index(0), index(m_items.size() - 1), {NotificationRuleRole});
+    if (!m_items.isEmpty()) {
+        Q_EMIT dataChanged(index(0), index(m_items.size() - 1), {NotificationRuleRole});
+    }
 }
 
 void RosterModel::handleMessageAdded(const Message &message, MessageOrigin origin)
@@ -582,7 +583,7 @@ void RosterModel::handleMessageAdded(const Message &message, MessageOrigin origi
         return;
     }
 
-    await(updateLastMessage(itr, message), this, [this, message, origin, itr](QList<int> &&changedRoles) mutable {
+    updateLastMessage(itr, message).then(this, [this, message, origin, itr](QList<int> &&changedRoles) mutable {
         // unread messages counter
         std::optional<int> newUnreadMessages;
 
@@ -628,7 +629,7 @@ void RosterModel::handleMessageUpdated(const Message &message)
         return;
     }
 
-    await(updateLastMessage(itr, message), this, [this, itr](QList<int> &&changedRoles) mutable {
+    updateLastMessage(itr, message).then(this, [this, itr](QList<int> &&changedRoles) mutable {
         if (!changedRoles.isEmpty()) {
             informAboutChangedData(itr, changedRoles);
         }
@@ -699,7 +700,7 @@ void RosterModel::handleMessageRemoved(const Message &newLastMessage)
         return;
     }
 
-    await(updateLastMessage(itr, newLastMessage, false), this, [this, itr](QList<int> &&changedRoles) mutable {
+    updateLastMessage(itr, newLastMessage, false).then(this, [this, itr](QList<int> &&changedRoles) mutable {
         if (!changedRoles.isEmpty()) {
             informAboutChangedData(itr, changedRoles);
         }
