@@ -17,6 +17,7 @@
 // Kaidan
 #include "AvatarFileStorage.h"
 #include "Kaidan.h"
+#include "KaidanCoreLog.h"
 #include "VCardCache.h"
 
 VCardManager::VCardManager(ClientWorker *clientWorker, QXmppClient *client, AvatarFileStorage *avatars, QObject *parent)
@@ -48,7 +49,7 @@ void VCardManager::requestVCard(const QString &jid)
     if (m_client->state() == QXmppClient::ConnectedState)
         m_manager->requestVCard(jid);
     else
-        qWarning() << "[VCardManager] Could not fetch vCard: Not connected to a server";
+        qCWarning(KAIDAN_CORE_LOG) << "Could not fetch vCard: Not connected to a server";
 }
 
 void VCardManager::handleVCardReceived(const QXmppVCardIq &iq)
@@ -65,7 +66,7 @@ void VCardManager::requestClientVCard()
     if (m_client->state() == QXmppClient::ConnectedState)
         m_manager->requestClientVCard();
     else
-        qWarning() << "[VCardManager] Could not fetch own vCard: Not connected to a server";
+        qCWarning(KAIDAN_CORE_LOG) << "Could not fetch own vCard: Not connected to a server";
 }
 
 void VCardManager::handleClientVCardReceived()
