@@ -2,17 +2,19 @@
 //
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#include "../src/Database.h"
-#include "../src/Algorithms.h"
-#include "../src/SqlUtils.h"
-
+// std
 #include <ranges>
-
+// Qt
 #include <QSqlDatabase>
 #include <QSqlField>
 #include <QSqlQuery>
 #include <QSqlRecord>
 #include <QTest>
+// Kaidan
+#include "Algorithms.h"
+#include "Database.h"
+#include "SqlUtils.h"
+#include "Test.h"
 
 using namespace SqlUtils;
 using std::ranges::sort;
@@ -40,7 +42,7 @@ static auto fieldNames(const QSqlRecord &record)
     return fieldNames;
 }
 
-class DatabaseTest : public QObject
+class DatabaseTest : public Test
 {
     Q_OBJECT
 
@@ -114,10 +116,10 @@ void DatabaseTest::conversion()
             }
 
             // check data type
-            if (fieldC.type() != fieldN.type()) {
+            if (fieldC.metaType() != fieldN.metaType()) {
                 qDebug() << tableName << fieldName << "data type mismatch!";
-                qDebug() << "  Conversion variant:" << fieldC.type();
-                qDebug() << "  New variant is:" << fieldN.type();
+                qDebug() << "  Conversion variant:" << fieldC.metaType();
+                qDebug() << "  New variant is:" << fieldN.metaType();
                 QFAIL("Field data type of conversion/new variant does not match.");
             }
         }
