@@ -2,21 +2,26 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
+// Qt
+#include <QJsonArray>
+#include <QSignalSpy>
 #include <QTest>
-
-#include "../src/PublicGroupChat.h"
-#include "../src/PublicGroupChatModel.h"
-#include "../src/PublicGroupChatProxyModel.h"
-#include "../src/PublicGroupChatSearchManager.h"
+#include <QTimer>
+// Kaidan
+#include "PublicGroupChat.h"
+#include "PublicGroupChatModel.h"
+#include "PublicGroupChatProxyModel.h"
+#include "PublicGroupChatSearchManager.h"
+#include "Test.h"
 
 #define REQUEST_TIMEOUT static_cast<int>((std::chrono::milliseconds(PublicGroupChatSearchManager::RequestTimeout) * 1.2).count())
 
-class GroupChatTest : public QObject
+class PublicGroupChatTest : public Test
 {
     Q_OBJECT
 
 private Q_SLOTS:
-    void test_splitLanguages_data()
+    void testSplitLanguages_data()
     {
         QTest::addColumn<QString>("languages");
         QTest::addColumn<QStringList>("expected");
@@ -56,7 +61,7 @@ private Q_SLOTS:
                                            };
     }
 
-    void test_splitLanguages()
+    void testSplitLanguages()
     {
         QFETCH(QString, languages);
         QFETCH(QStringList, expected);
@@ -64,7 +69,7 @@ private Q_SLOTS:
         QCOMPARE(PublicGroupChat::splitLanguages(languages), expected);
     }
 
-    void test_GroupChat()
+    void testPublicGroupChat()
     {
         PublicGroupChat groupChat;
 
@@ -86,7 +91,7 @@ private Q_SLOTS:
         QVERIFY(groupChat == PublicGroupChat(object));
     }
 
-    void test_GroupChats()
+    void testPublicGroupChats()
     {
         PublicGroupChat groupChat1;
 
@@ -128,7 +133,7 @@ private Q_SLOTS:
         QVERIFY(groupChats == (PublicGroupChats{PublicGroupChat{object1}, PublicGroupChat{object2}}));
     }
 
-    void test_GroupChatSearchManager_GroupChatModel()
+    void testGroupChatSearchManagerAndGroupChatModel()
     {
         PublicGroupChatSearchManager manager;
         PublicGroupChatModel model;
@@ -147,21 +152,37 @@ private Q_SLOTS:
         QVERIFY(model.rowCount() == manager.cachedGroupChats().count());
 
         // requestAll and cancel after 1 second
+        QVERIFY(!manager.isRunning());
         manager.requestAll();
-        QTimer::singleShot(1000, &manager, &PublicGroupChatSearchManager::cancel);
+
+        QTimer cancelTimer;
+        cancelTimer.setSingleShot(true);
+        cancelTimer.setInterval(1000);
+        cancelTimer.callOnTimeout(&manager, &PublicGroupChatSearchManager::cancel);
+
+        cancelTimer.start();
 
         QVERIFY(spyIsRunning.wait(2000));
         QVERIFY(spyError.isEmpty());
-        QVERIFY(spyReceived.isEmpty());
+        // Depending on how fast the network is, the cancellation can be requested too late (data already received).
+        QVERIFY(spyReceived.size() <= 1);
         QCOMPARE(spyIsRunning.count(), 2);
         QCOMPARE(spyIsRunning.constFirst().constFirst().toBool(), true);
         QCOMPARE(spyIsRunning.constLast().constFirst().toBool(), false);
-        QVERIFY(manager.cachedGroupChats().isEmpty());
+        if (spyReceived.isEmpty()) {
+            QVERIFY(manager.cachedGroupChats().isEmpty());
+        } else {
+            QVERIFY(manager.cachedGroupChats().size() >= 1);
+        }
         QVERIFY(model.rowCount() == manager.cachedGroupChats().count());
 
+        // In case the network was too fast, avoid canceling the next request.
+        cancelTimer.stop();
+
         clearSpies();
 
         // Really requestAll
+        QVERIFY(!manager.isRunning());
         manager.requestAll();
 
         QVERIFY(spyIsRunning.wait(REQUEST_TIMEOUT));
@@ -182,7 +203,7 @@ private Q_SLOTS:
         QCOMPARE(groupChat.description(), index.data(Qt::ToolTipRole));
     }
 
-    void test_GroupChatProxyModel_data()
+    void testPublicGroupChatProxyModel_data()
     {
         using Role = PublicGroupChatModel::CustomRole;
         QTest::addColumn<Role>("sortRole");
@@ -390,9 +411,9 @@ private Q_SLOTS:
         QTest::newRow("Languages / Languages / fr") << Role::Languages << Role::Languages << QStringLiteral("fr")
                                                     << QList<QStringList>{
                                                            {
-                                                               QStringList{"Bookri"},
-                                                               QStringList{"bookri@jabber.com"},
-                                                               QStringList{"fr"},
+                                                               QStringList{QStringLiteral("Bookri")},
+                                                               QStringList{QStringLiteral("bookri@jabber.com")},
+                                                               QStringList{QStringLiteral("fr")},
                                                            },
                                                        };
 
@@ -456,7 +477,7 @@ private Q_SLOTS:
                                                            };
     }
 
-    void test_GroupChatProxyModel()
+    void testPublicGroupChatProxyModel()
     {
         using Role = PublicGroupChatModel::CustomRole;
         PublicGroupChatModel model;
@@ -521,5 +542,5 @@ private Q_SLOTS:
     }
 };
 
-QTEST_GUILESS_MAIN(GroupChatTest)
+QTEST_GUILESS_MAIN(PublicGroupChatTest)
 #include "PublicGroupChatTest.moc"
