@@ -3,21 +3,23 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later OR LGPL-2.1-or-later
 
-#include <QXmppTrustLevel.h>
-
+// Qt
 #include <QTest>
-
-#include "../src/Database.h"
-#include "../src/TrustDb.h"
-#include "utils.h"
+// QXmpp
+#include <QXmppTrustLevel.h>
 #include <QXmppTrustMessageKeyOwner.h>
+// Kaidan
+#include "Database.h"
+#include "Test.h"
+#include "TestUtils.h"
+#include "TrustDb.h"
 
 using namespace QXmpp;
 
-constexpr auto ns_omemo = "urn:xmpp:omemo:2";
-constexpr auto ns_ox = "urn:xmpp:ox:0";
+const QString ns_omemo = QStringLiteral("urn:xmpp:omemo:2");
+const QString ns_ox = QStringLiteral("urn:xmpp:ox:0");
 
-class TrustDbTest : public QObject
+class TrustDbTest : public Test
 {
     Q_OBJECT
     Q_SLOT void testSecurityPolicy();
@@ -30,7 +32,7 @@ class TrustDbTest : public QObject
 
 private:
     Database db;
-    TrustDb storage = TrustDb(&db, this, "account@example.org");
+    TrustDb storage = TrustDb(&db, this, QStringLiteral("account@example.org"));
 };
 
 void TrustDbTest::testSecurityPolicy()
@@ -73,18 +75,18 @@ void TrustDbTest::testKeys()
     QVERIFY(wait(this, storage.keys(ns_omemo)).isEmpty());
 
     // no OMEMO keys (via JIDs)
-    QVERIFY(wait(this, storage.keys(ns_omemo, {"alice@example.org", "bob@example.com"})).isEmpty());
+    QVERIFY(wait(this, storage.keys(ns_omemo, {QStringLiteral("alice@example.org"), QStringLiteral("bob@example.com")})).isEmpty());
 
     // no automatically trusted and authenticated OMEMO keys
     QVERIFY(wait(this, storage.keys(ns_omemo, TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)).isEmpty());
 
     // no automatically trusted and authenticated OMEMO key from Alice
-    QVERIFY(!wait(this, storage.hasKey(ns_omemo, "alice@example.org", TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)));
+    QVERIFY(!wait(this, storage.hasKey(ns_omemo, QStringLiteral("alice@example.org"), TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)));
 
     // Store keys with the default trust level.
     storage.addKeys(
         ns_omemo,
-        "alice@example.org",
+        QStringLiteral("alice@example.org"),
         {QByteArray::fromBase64(("WaAnpWyW1hnFooH3oJo9Ba5XYoksnLPeJRTAjxPbv38=")), QByteArray::fromBase64(("/1eK3R2LtjPBT3el8f0q4DvzqUJSfFy5fkKkKPNFNYw="))});
 
     struct Key {
@@ -97,26 +99,39 @@ void TrustDbTest::testKeys()
         wait(this, storage.addKeys(key.encryption, key.jid, {key.key}, key.trust));
     };
     std::vector<Key> keys = {
-        Key{ns_omemo, "alice@example.org", QByteArray::fromBase64("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="), TrustLevel::ManuallyDistrusted},
-        Key{ns_omemo, "alice@example.org", QByteArray::fromBase64("Ciemp4ZNzRJxnRD+k28vAie0kXJrwl4IrbfDy7n6OxE="), TrustLevel::AutomaticallyTrusted},
-        Key{ns_omemo, "bob@example.com", QByteArray::fromBase64("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg="), TrustLevel::AutomaticallyTrusted},
-        Key{ns_omemo, "bob@example.com", QByteArray::fromBase64("2fhJtrgoMJxfLI3084/YkYh9paqiSiLFDVL2m0qAgX4="), TrustLevel::ManuallyTrusted},
-        Key{ns_omemo, "bob@example.com", QByteArray::fromBase64("tCP1CI3pqSTVGzFYFyPYUMfMZ9Ck/msmfD0wH/VtJBM="), TrustLevel::ManuallyTrusted},
-        Key{ns_omemo, "bob@example.com", QByteArray::fromBase64("YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8="), TrustLevel::Authenticated},
-        Key{ns_ox, "alice@example.org", QByteArray::fromBase64("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="), TrustLevel::Authenticated},
-        Key{ns_ox, "alice@example.org", QByteArray::fromBase64("IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA="), TrustLevel::Authenticated},
+        Key{ns_omemo,
+            QStringLiteral("alice@example.org"),
+            QByteArray::fromBase64("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="),
+            TrustLevel::ManuallyDistrusted},
+        Key{ns_omemo,
+            QStringLiteral("alice@example.org"),
+            QByteArray::fromBase64("Ciemp4ZNzRJxnRD+k28vAie0kXJrwl4IrbfDy7n6OxE="),
+            TrustLevel::AutomaticallyTrusted},
+        Key{ns_omemo,
+            QStringLiteral("bob@example.com"),
+            QByteArray::fromBase64("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg="),
+            TrustLevel::AutomaticallyTrusted},
+        Key{ns_omemo, QStringLiteral("bob@example.com"), QByteArray::fromBase64("2fhJtrgoMJxfLI3084/YkYh9paqiSiLFDVL2m0qAgX4="), TrustLevel::ManuallyTrusted},
+        Key{ns_omemo, QStringLiteral("bob@example.com"), QByteArray::fromBase64("tCP1CI3pqSTVGzFYFyPYUMfMZ9Ck/msmfD0wH/VtJBM="), TrustLevel::ManuallyTrusted},
+        Key{ns_omemo, QStringLiteral("bob@example.com"), QByteArray::fromBase64("YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8="), TrustLevel::Authenticated},
+        Key{ns_ox, QStringLiteral("alice@example.org"), QByteArray::fromBase64("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="), TrustLevel::Authenticated},
+        Key{ns_ox, QStringLiteral("alice@example.org"), QByteArray::fromBase64("IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA="), TrustLevel::Authenticated},
     };
     std::for_each(keys.cbegin(), keys.cend(), addKey);
 
     QMultiHash<QString, QByteArray> automaticallyDistrustedKeys = {
-        {"alice@example.org", QByteArray::fromBase64(("WaAnpWyW1hnFooH3oJo9Ba5XYoksnLPeJRTAjxPbv38="))},
-        {"alice@example.org", QByteArray::fromBase64(("/1eK3R2LtjPBT3el8f0q4DvzqUJSfFy5fkKkKPNFNYw="))}};
-    QMultiHash<QString, QByteArray> manuallyDistrustedKeys = {{"alice@example.org", QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="))}};
-    QMultiHash<QString, QByteArray> automaticallyTrustedKeys = {{"alice@example.org", QByteArray::fromBase64(("Ciemp4ZNzRJxnRD+k28vAie0kXJrwl4IrbfDy7n6OxE="))},
-                                                                {"bob@example.com", QByteArray::fromBase64(("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg="))}};
-    QMultiHash<QString, QByteArray> manuallyTrustedKeys = {{"bob@example.com", QByteArray::fromBase64(("tCP1CI3pqSTVGzFYFyPYUMfMZ9Ck/msmfD0wH/VtJBM="))},
-                                                           {"bob@example.com", QByteArray::fromBase64(("2fhJtrgoMJxfLI3084/YkYh9paqiSiLFDVL2m0qAgX4="))}};
-    QMultiHash<QString, QByteArray> authenticatedKeys = {{"bob@example.com", QByteArray::fromBase64(("YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8="))}};
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("WaAnpWyW1hnFooH3oJo9Ba5XYoksnLPeJRTAjxPbv38="))},
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("/1eK3R2LtjPBT3el8f0q4DvzqUJSfFy5fkKkKPNFNYw="))}};
+    QMultiHash<QString, QByteArray> manuallyDistrustedKeys = {
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="))}};
+    QMultiHash<QString, QByteArray> automaticallyTrustedKeys = {
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("Ciemp4ZNzRJxnRD+k28vAie0kXJrwl4IrbfDy7n6OxE="))},
+        {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg="))}};
+    QMultiHash<QString, QByteArray> manuallyTrustedKeys = {
+        {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("tCP1CI3pqSTVGzFYFyPYUMfMZ9Ck/msmfD0wH/VtJBM="))},
+        {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("2fhJtrgoMJxfLI3084/YkYh9paqiSiLFDVL2m0qAgX4="))}};
+    QMultiHash<QString, QByteArray> authenticatedKeys = {
+        {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8="))}};
 
     QHash<QByteArray, TrustLevel> keysAlice = {{QByteArray::fromBase64("WaAnpWyW1hnFooH3oJo9Ba5XYoksnLPeJRTAjxPbv38="), TrustLevel::AutomaticallyDistrusted},
                                                {QByteArray::fromBase64("/1eK3R2LtjPBT3el8f0q4DvzqUJSfFy5fkKkKPNFNYw="), TrustLevel::AutomaticallyDistrusted},
@@ -140,33 +155,37 @@ void TrustDbTest::testKeys()
              QHash({std::pair(TrustLevel::AutomaticallyTrusted, automaticallyTrustedKeys), std::pair(TrustLevel::Authenticated, authenticatedKeys)}));
 
     // all OMEMO keys (via JIDs)
-    QCOMPARE(wait(this, storage.keys(ns_omemo, {"alice@example.org", "bob@example.com"})),
-             TrustDb::KeysByOwner({std::pair("alice@example.org", keysAlice), std::pair("bob@example.com", keysBob)}));
+    QCOMPARE(wait(this, storage.keys(ns_omemo, {QStringLiteral("alice@example.org"), QStringLiteral("bob@example.com")})),
+             TrustDb::KeysByOwner({std::pair(QStringLiteral("alice@example.org"), keysAlice), std::pair(QStringLiteral("bob@example.com"), keysBob)}));
 
     // Alice's OMEMO keys
-    QCOMPARE(wait(this, storage.keys(ns_omemo, {"alice@example.org"})), TrustDb::KeysByOwner({std::pair("alice@example.org", keysAlice)}));
+    QCOMPARE(wait(this, storage.keys(ns_omemo, {QStringLiteral("alice@example.org")})),
+             TrustDb::KeysByOwner({std::pair(QStringLiteral("alice@example.org"), keysAlice)}));
 
     keysAlice = {{QByteArray::fromBase64(("Ciemp4ZNzRJxnRD+k28vAie0kXJrwl4IrbfDy7n6OxE=")), TrustLevel::AutomaticallyTrusted}};
     keysBob = {{QByteArray::fromBase64(("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg=")), TrustLevel::AutomaticallyTrusted},
                {QByteArray::fromBase64(("YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8=")), TrustLevel::Authenticated}};
 
     // automatically trusted and authenticated OMEMO keys (via JIDs)
-    QCOMPARE(wait(this, storage.keys(ns_omemo, {"alice@example.org", "bob@example.com"}, TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)),
-             TrustDb::KeysByOwner({std::pair("alice@example.org", keysAlice), std::pair("bob@example.com", keysBob)}));
+    QCOMPARE(wait(this,
+                  storage.keys(ns_omemo,
+                               {QStringLiteral("alice@example.org"), QStringLiteral("bob@example.com")},
+                               TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)),
+             TrustDb::KeysByOwner({std::pair(QStringLiteral("alice@example.org"), keysAlice), std::pair(QStringLiteral("bob@example.com"), keysBob)}));
 
     // Alice's automatically trusted and authenticated OMEMO keys
-    QCOMPARE(wait(this, storage.keys(ns_omemo, {"alice@example.org"}, TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)),
-             TrustDb::KeysByOwner({std::pair("alice@example.org", keysAlice)}));
+    QCOMPARE(wait(this, storage.keys(ns_omemo, {QStringLiteral("alice@example.org")}, TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)),
+             TrustDb::KeysByOwner({std::pair(QStringLiteral("alice@example.org"), keysAlice)}));
 
     // at least one automatically trusted or authenticated OMEMO key from Alice
-    QVERIFY(wait(this, storage.hasKey(ns_omemo, "alice@example.org", TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)));
+    QVERIFY(wait(this, storage.hasKey(ns_omemo, QStringLiteral("alice@example.org"), TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)));
 
     storage.removeKeys(
         ns_omemo,
         {QByteArray::fromBase64("WaAnpWyW1hnFooH3oJo9Ba5XYoksnLPeJRTAjxPbv38="), QByteArray::fromBase64("Ciemp4ZNzRJxnRD+k28vAie0kXJrwl4IrbfDy7n6OxE=")});
 
-    automaticallyDistrustedKeys = {{"alice@example.org", QByteArray::fromBase64(("/1eK3R2LtjPBT3el8f0q4DvzqUJSfFy5fkKkKPNFNYw="))}};
-    automaticallyTrustedKeys = {{"bob@example.com", QByteArray::fromBase64(("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg="))}};
+    automaticallyDistrustedKeys = {{QStringLiteral("alice@example.org"), QByteArray::fromBase64(("/1eK3R2LtjPBT3el8f0q4DvzqUJSfFy5fkKkKPNFNYw="))}};
+    automaticallyTrustedKeys = {{QStringLiteral("bob@example.com"), QByteArray::fromBase64(("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg="))}};
 
     keysAlice = {{QByteArray::fromBase64(("/1eK3R2LtjPBT3el8f0q4DvzqUJSfFy5fkKkKPNFNYw=")), TrustLevel::AutomaticallyDistrusted},
                  {QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ=")), TrustLevel::ManuallyDistrusted}};
@@ -184,24 +203,28 @@ void TrustDbTest::testKeys()
                     std::pair(TrustLevel::Authenticated, authenticatedKeys)}));
 
     // OMEMO keys after removal (via JIDs)
-    QCOMPARE(wait(this, storage.keys(ns_omemo, {"alice@example.org", "bob@example.com"})),
-             TrustDb::KeysByOwner({std::pair("alice@example.org", keysAlice), std::pair("bob@example.com", keysBob)}));
+    QCOMPARE(wait(this, storage.keys(ns_omemo, {QStringLiteral("alice@example.org"), QStringLiteral("bob@example.com")})),
+             TrustDb::KeysByOwner({std::pair(QStringLiteral("alice@example.org"), keysAlice), std::pair(QStringLiteral("bob@example.com"), keysBob)}));
 
     // Alice's OMEMO keys after removal
-    QCOMPARE(wait(this, storage.keys(ns_omemo, {"alice@example.org"})), TrustDb::KeysByOwner({std::pair("alice@example.org", keysAlice)}));
+    QCOMPARE(wait(this, storage.keys(ns_omemo, {QStringLiteral("alice@example.org")})),
+             TrustDb::KeysByOwner({std::pair(QStringLiteral("alice@example.org"), keysAlice)}));
 
     keysAlice = {{QByteArray::fromBase64(("Ciemp4ZNzRJxnRD+k28vAie0kXJrwl4IrbfDy7n6OxE=")), TrustLevel::AutomaticallyTrusted}};
     keysBob = {{QByteArray::fromBase64(("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg=")), TrustLevel::AutomaticallyTrusted},
                {QByteArray::fromBase64(("YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8=")), TrustLevel::Authenticated}};
 
     // automatically trusted and authenticated OMEMO keys after removal (via JIDs)
-    QCOMPARE(wait(this, storage.keys(ns_omemo, {"alice@example.org", "bob@example.com"}, TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)),
-             TrustDb::KeysByOwner({std::pair("bob@example.com", keysBob)}));
+    QCOMPARE(wait(this,
+                  storage.keys(ns_omemo,
+                               {QStringLiteral("alice@example.org"), QStringLiteral("bob@example.com")},
+                               TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)),
+             TrustDb::KeysByOwner({std::pair(QStringLiteral("bob@example.com"), keysBob)}));
 
     // Alice's automatically trusted and authenticated OMEMO keys after removal
-    QVERIFY(wait(this, storage.keys(ns_omemo, {"alice@example.org"}, TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)).isEmpty());
+    QVERIFY(wait(this, storage.keys(ns_omemo, {QStringLiteral("alice@example.org")}, TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated)).isEmpty());
 
-    storage.removeKeys(ns_omemo, "alice@example.org");
+    storage.removeKeys(ns_omemo, QStringLiteral("alice@example.org"));
 
     // OMEMO keys after removing Alice's keys
     QCOMPARE(wait(this, storage.keys(ns_omemo)),
@@ -214,8 +237,8 @@ void TrustDbTest::testKeys()
     // no stored OMEMO keys
     QVERIFY(wait(this, storage.keys(ns_omemo)).isEmpty());
 
-    authenticatedKeys = {{"alice@example.org", QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="))},
-                         {"alice@example.org", QByteArray::fromBase64(("IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA="))}};
+    authenticatedKeys = {{QStringLiteral("alice@example.org"), QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="))},
+                         {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA="))}};
 
     keysAlice = {{QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ=")), TrustLevel::Authenticated},
                  {QByteArray::fromBase64(("IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA=")), TrustLevel::Authenticated}};
@@ -224,10 +247,11 @@ void TrustDbTest::testKeys()
     QCOMPARE(wait(this, storage.keys(ns_ox)), QHash({std::pair(TrustLevel::Authenticated, authenticatedKeys)}));
 
     // remaining OX keys (via JIDs)
-    QCOMPARE(wait(this, storage.keys(ns_ox, {"alice@example.org", "bob@example.com"})), TrustDb::KeysByOwner({std::pair("alice@example.org", keysAlice)}));
+    QCOMPARE(wait(this, storage.keys(ns_ox, {QStringLiteral("alice@example.org"), QStringLiteral("bob@example.com")})),
+             TrustDb::KeysByOwner({std::pair(QStringLiteral("alice@example.org"), keysAlice)}));
 
     // Alice's remaining OX keys
-    QCOMPARE(wait(this, storage.keys(ns_ox, {"alice@example.org"})), TrustDb::KeysByOwner({{"alice@example.org", keysAlice}}));
+    QCOMPARE(wait(this, storage.keys(ns_ox, {QStringLiteral("alice@example.org")})), TrustDb::KeysByOwner({{QStringLiteral("alice@example.org"), keysAlice}}));
 
     storage.removeKeys(ns_ox);
 
@@ -235,69 +259,92 @@ void TrustDbTest::testKeys()
     QVERIFY(wait(this, storage.keys(ns_ox)).isEmpty());
 
     // no stored OX keys (via JIDs)
-    QVERIFY(wait(this, storage.keys(ns_ox, {"alice@example.org", "bob@example.com"})).isEmpty());
+    QVERIFY(wait(this, storage.keys(ns_ox, {QStringLiteral("alice@example.org"), QStringLiteral("bob@example.com")})).isEmpty());
 
     // no automatically trusted or authenticated OX key from Alice
-    auto hasKeyResult = wait(this, storage.hasKey(ns_ox, "alice@example.org", TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated));
+    auto hasKeyResult = wait(this, storage.hasKey(ns_ox, QStringLiteral("alice@example.org"), TrustLevel::AutomaticallyTrusted | TrustLevel::Authenticated));
     QVERIFY(!hasKeyResult);
 }
 
 void TrustDbTest::testTrustLevels()
 {
-    storage.addKeys(ns_ox, "alice@example.org", {QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU="))}, TrustLevel::AutomaticallyTrusted);
+    storage.addKeys(ns_ox,
+                    QStringLiteral("alice@example.org"),
+                    {QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU="))},
+                    TrustLevel::AutomaticallyTrusted);
 
     storage.addKeys(
         ns_omemo,
-        "alice@example.org",
+        QStringLiteral("alice@example.org"),
         {QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU=")), QByteArray::fromBase64(("JU4pT7Ivpigtl+7QE87Bkq4r/C/mhI1FCjY5Wmjbtwg="))},
         TrustLevel::AutomaticallyTrusted);
 
-    storage.addKeys(ns_omemo, "alice@example.org", {QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="))}, TrustLevel::ManuallyTrusted);
+    storage.addKeys(ns_omemo,
+                    QStringLiteral("alice@example.org"),
+                    {QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="))},
+                    TrustLevel::ManuallyTrusted);
 
-    storage.addKeys(ns_omemo, "bob@example.com", {QByteArray::fromBase64(("9E51lG3vVmUn8CM7/AIcmIlLP2HPl6Ao0/VSf4VT/oA="))}, TrustLevel::AutomaticallyTrusted);
+    storage.addKeys(ns_omemo,
+                    QStringLiteral("bob@example.com"),
+                    {QByteArray::fromBase64(("9E51lG3vVmUn8CM7/AIcmIlLP2HPl6Ao0/VSf4VT/oA="))},
+                    TrustLevel::AutomaticallyTrusted);
 
-    QCOMPARE(wait(this, storage.trustLevel(ns_omemo, "alice@example.org", QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU=")))),
-             TrustLevel::AutomaticallyTrusted);
+    QCOMPARE(
+        wait(this, storage.trustLevel(ns_omemo, QStringLiteral("alice@example.org"), QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU=")))),
+        TrustLevel::AutomaticallyTrusted);
 
     storage.setTrustLevel(ns_omemo,
-                          {{"alice@example.org", QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU="))},
-                           {"bob@example.com", QByteArray::fromBase64(("9E51lG3vVmUn8CM7/AIcmIlLP2HPl6Ao0/VSf4VT/oA="))}},
+                          {{QStringLiteral("alice@example.org"), QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU="))},
+                           {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("9E51lG3vVmUn8CM7/AIcmIlLP2HPl6Ao0/VSf4VT/oA="))}},
                           TrustLevel::Authenticated);
 
-    QCOMPARE(int(wait(this, storage.trustLevel(ns_omemo, "alice@example.org", QByteArray::fromBase64("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU=")))),
-             int(TrustLevel::Authenticated));
+    QCOMPARE(
+        int(wait(this,
+                 storage.trustLevel(ns_omemo, QStringLiteral("alice@example.org"), QByteArray::fromBase64("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU=")))),
+        int(TrustLevel::Authenticated));
 
-    QCOMPARE(wait(this, storage.trustLevel(ns_omemo, "bob@example.com", QByteArray::fromBase64(("9E51lG3vVmUn8CM7/AIcmIlLP2HPl6Ao0/VSf4VT/oA=")))),
-             TrustLevel::Authenticated);
+    QCOMPARE(
+        wait(this, storage.trustLevel(ns_omemo, QStringLiteral("bob@example.com"), QByteArray::fromBase64(("9E51lG3vVmUn8CM7/AIcmIlLP2HPl6Ao0/VSf4VT/oA=")))),
+        TrustLevel::Authenticated);
 
     // Set the trust level of a key that is not stored yet.
     // It is added to the storage automatically.
     wait(this,
          storage.setTrustLevel(ns_omemo,
-                               {{"alice@example.org", QByteArray::fromBase64("9w6oPjKyGSALd9gHq7sNOdOAkD5bHUVOKACNs89FjkA=")}},
+                               {{QStringLiteral("alice@example.org"), QByteArray::fromBase64("9w6oPjKyGSALd9gHq7sNOdOAkD5bHUVOKACNs89FjkA=")}},
                                TrustLevel::ManuallyTrusted));
 
-    QCOMPARE(int(wait(this, storage.trustLevel(ns_omemo, "alice@example.org", QByteArray::fromBase64("9w6oPjKyGSALd9gHq7sNOdOAkD5bHUVOKACNs89FjkA=")))),
-             int(TrustLevel::ManuallyTrusted));
+    QCOMPARE(
+        int(wait(this,
+                 storage.trustLevel(ns_omemo, QStringLiteral("alice@example.org"), QByteArray::fromBase64("9w6oPjKyGSALd9gHq7sNOdOAkD5bHUVOKACNs89FjkA=")))),
+        int(TrustLevel::ManuallyTrusted));
 
     // Try to retrieve the trust level of a key that is not stored yet.
     // The default value is returned.
-    QCOMPARE(wait(this, storage.trustLevel(ns_omemo, "someone@example.org", QByteArray::fromBase64("WXL4EDfzUGbVPQWjT9pmBeiCpCBzYZv3lUAaj+UbPyE="))),
-             TrustLevel::Undecided);
+    QCOMPARE(
+        wait(this, storage.trustLevel(ns_omemo, QStringLiteral("someone@example.org"), QByteArray::fromBase64("WXL4EDfzUGbVPQWjT9pmBeiCpCBzYZv3lUAaj+UbPyE="))),
+        TrustLevel::Undecided);
 
     // Set the trust levels of all authenticated keys belonging to Alice and
     // Bob.
-    storage.setTrustLevel(ns_omemo, {"alice@example.org", "bob@example.com"}, TrustLevel::Authenticated, TrustLevel::ManuallyDistrusted);
+    storage.setTrustLevel(ns_omemo,
+                          {QStringLiteral("alice@example.org"), QStringLiteral("bob@example.com")},
+                          TrustLevel::Authenticated,
+                          TrustLevel::ManuallyDistrusted);
 
-    QCOMPARE(wait(this, storage.trustLevel(ns_omemo, "alice@example.org", QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU=")))),
-             TrustLevel::ManuallyDistrusted);
+    QCOMPARE(
+        wait(this, storage.trustLevel(ns_omemo, QStringLiteral("alice@example.org"), QByteArray::fromBase64(("AZ/cF4OrUOILKO1gQBf62pQevOhBJ2NyHnXLwM4FDZU=")))),
+        TrustLevel::ManuallyDistrusted);
 
-    QCOMPARE(wait(this, storage.trustLevel(ns_omemo, "bob@example.com", QByteArray::fromBase64("9E51lG3vVmUn8CM7/AIcmIlLP2HPl6Ao0/VSf4VT/oA="))),
-             TrustLevel::ManuallyDistrusted);
+    QCOMPARE(
+        wait(this, storage.trustLevel(ns_omemo, QStringLiteral("bob@example.com"), QByteArray::fromBase64("9E51lG3vVmUn8CM7/AIcmIlLP2HPl6Ao0/VSf4VT/oA="))),
+        TrustLevel::ManuallyDistrusted);
 
     // Verify that the default trust level is returned for an unknown key.
-    QCOMPARE(wait(this, storage.trustLevel(ns_omemo, "somebody@example.org", QByteArray::fromBase64(("wE06Gwf8f4DvDLFDoaCsGs8ibcUjf84WIOA2FAjPI3o=")))),
-             TrustLevel::Undecided);
+    QCOMPARE(
+        wait(this,
+             storage.trustLevel(ns_omemo, QStringLiteral("somebody@example.org"), QByteArray::fromBase64(("wE06Gwf8f4DvDLFDoaCsGs8ibcUjf84WIOA2FAjPI3o=")))),
+        TrustLevel::Undecided);
 
     storage.removeKeys(ns_ox);
     storage.removeKeys(ns_omemo);
@@ -313,30 +360,39 @@ void TrustDbTest::testResetAll()
 
     storage.addKeys(
         ns_omemo,
-        "alice@example.org",
+        QStringLiteral("alice@example.org"),
         {QByteArray::fromBase64("WaAnpWyW1hnFooH3oJo9Ba5XYoksnLPeJRTAjxPbv38="), QByteArray::fromBase64("/1eK3R2LtjPBT3el8f0q4DvzqUJSfFy5fkKkKPNFNYw=")});
 
-    storage.addKeys(ns_omemo, "alice@example.org", {QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="))}, TrustLevel::ManuallyDistrusted);
+    storage.addKeys(ns_omemo,
+                    QStringLiteral("alice@example.org"),
+                    {QByteArray::fromBase64(("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="))},
+                    TrustLevel::ManuallyDistrusted);
 
     storage.addKeys(ns_omemo,
-                    "alice@example.org",
+                    QStringLiteral("alice@example.org"),
                     {QByteArray::fromBase64(("Ciemp4ZNzRJxnRD+k28vAie0kXJrwl4IrbfDy7n6OxE="))},
                     TrustLevel::AutomaticallyTrusted);
 
-    storage.addKeys(ns_omemo, "bob@example.com", {QByteArray::fromBase64(("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg="))}, TrustLevel::AutomaticallyTrusted);
+    storage.addKeys(ns_omemo,
+                    QStringLiteral("bob@example.com"),
+                    {QByteArray::fromBase64(("rvSXBRd+EICMhQvVgcREQJxxP+T4EBmai4mYHBfJQGg="))},
+                    TrustLevel::AutomaticallyTrusted);
 
     storage.addKeys(ns_omemo,
-                    "bob@example.com",
+                    QStringLiteral("bob@example.com"),
                     {QByteArray::fromBase64(("tCP1CI3pqSTVGzFYFyPYUMfMZ9Ck/msmfD0wH/VtJBM=")),
                      QByteArray::fromBase64(("2fhJtrgoMJxfLI3084/"
                                              "YkYh9paqiSiLFDVL2m0qAgX4="))},
                     TrustLevel::ManuallyTrusted);
 
-    storage.addKeys(ns_omemo, "bob@example.com", {QByteArray::fromBase64(("YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8="))}, TrustLevel::Authenticated);
+    storage.addKeys(ns_omemo,
+                    QStringLiteral("bob@example.com"),
+                    {QByteArray::fromBase64(("YjVI04NcbTPvXLaA95RO84HPcSvyOgEZ2r5cTyUs0C8="))},
+                    TrustLevel::Authenticated);
 
     storage.addKeys(
         ns_ox,
-        "alice@example.org",
+        QStringLiteral("alice@example.org"),
         {QByteArray::fromBase64("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="), QByteArray::fromBase64("IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA=")},
         TrustLevel::Authenticated);
 
@@ -347,8 +403,9 @@ void TrustDbTest::testResetAll()
     QCOMPARE(wait(this, storage.ownKey(ns_ox)), QByteArray::fromBase64("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ="));
     QVERIFY(wait(this, storage.keys(ns_omemo)).isEmpty());
 
-    const QMultiHash<QString, QByteArray> authenticatedKeys = {{"alice@example.org", QByteArray::fromBase64("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ=")},
-                                                               {"alice@example.org", QByteArray::fromBase64("IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA=")}};
+    const QMultiHash<QString, QByteArray> authenticatedKeys = {
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64("aFABnX7Q/rbTgjBySYzrT2FsYCVYb49mbca5yB734KQ=")},
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64("IhpPjiKLchgrAG5cpSfTvdzPjZ5v6vTOluHEUehkgCA=")}};
 
     QCOMPARE(wait(this, storage.keys(ns_ox)), QHash({std::pair{TrustLevel::Authenticated, authenticatedKeys}}));
 
@@ -363,7 +420,7 @@ void TrustDbTest::atmTestKeysForPostponedTrustDecisions()
     // is set for both postponed authentication and distrusting.
     // Thus, it is only stored for postponed distrusting.
     QXmppTrustMessageKeyOwner keyOwnerAlice;
-    keyOwnerAlice.setJid("alice@example.org");
+    keyOwnerAlice.setJid(QStringLiteral("alice@example.org"));
     keyOwnerAlice.setTrustedKeys({QByteArray::fromBase64(("Wl53ZchbtAtCZQCHROiD20W7UnKTQgWQrjTHAVNw1ic=")),
                                   QByteArray::fromBase64(("QR05jrab7PFkSLhtdzyXrPfCqhkNCYCrlWATaBMTenE=")),
                                   QByteArray::fromBase64(("7y1t0LnmNBeXJka43XejFPLrKtQlSFATrYmy7xHaKYU="))});
@@ -371,7 +428,7 @@ void TrustDbTest::atmTestKeysForPostponedTrustDecisions()
         {QByteArray::fromBase64(("mB98hhdVps++skUuy4TGy/Vp6RQXLJO4JGf86FAUjyc=")), QByteArray::fromBase64(("7y1t0LnmNBeXJka43XejFPLrKtQlSFATrYmy7xHaKYU="))});
 
     QXmppTrustMessageKeyOwner keyOwnerBobTrustedKeys;
-    keyOwnerBobTrustedKeys.setJid("bob@example.com");
+    keyOwnerBobTrustedKeys.setJid(QStringLiteral("bob@example.com"));
     keyOwnerBobTrustedKeys.setTrustedKeys({QByteArray::fromBase64(("GgTqeRLp1M+MEenzFQym2oqer9PfHukS4brJDQl5ARE="))});
 
     storage.addKeysForPostponedTrustDecisions(ns_omemo,
@@ -379,14 +436,14 @@ void TrustDbTest::atmTestKeysForPostponedTrustDecisions()
                                               {keyOwnerAlice, keyOwnerBobTrustedKeys});
 
     QXmppTrustMessageKeyOwner keyOwnerBobDistrustedKeys;
-    keyOwnerBobDistrustedKeys.setJid("bob@example.com");
+    keyOwnerBobDistrustedKeys.setJid(QStringLiteral("bob@example.com"));
     keyOwnerBobDistrustedKeys.setDistrustedKeys(
         {QByteArray::fromBase64(("sD6ilugEBeKxPsdDEyX43LSGKHKWd5MFEdhT+4RpsxA=")), QByteArray::fromBase64(("X5tJ1D5rEeaeQE8eqhBKAj4KUZGYe3x+iHifaTBY1kM="))});
 
     storage.addKeysForPostponedTrustDecisions(ns_omemo, QByteArray::fromBase64(("IL5iwDQwquH7yjb5RAiIP+nvYiBUsNCXtKB8IpKc9QU=")), {keyOwnerBobDistrustedKeys});
 
     QXmppTrustMessageKeyOwner keyOwnerCarol;
-    keyOwnerCarol.setJid(("carol@example.net"));
+    keyOwnerCarol.setJid(QStringLiteral("carol@example.net"));
     keyOwnerCarol.setTrustedKeys(
         {QByteArray::fromBase64(("WcL+cEMpEeK+dpqg3Xd3amctzwP8h2MqwXcEzFf6LpU=")), QByteArray::fromBase64(("bH3R31z0N97K1fUwG3+bdBrVPuDfXguQapHudkfa5nE="))});
     keyOwnerCarol.setDistrustedKeys(
@@ -394,19 +451,21 @@ void TrustDbTest::atmTestKeysForPostponedTrustDecisions()
 
     storage.addKeysForPostponedTrustDecisions(ns_ox, QByteArray::fromBase64(("IL5iwDQwquH7yjb5RAiIP+nvYiBUsNCXtKB8IpKc9QU=")), {keyOwnerCarol});
 
-    QMultiHash<QString, QByteArray> trustedKeys = {{"alice@example.org", QByteArray::fromBase64(("Wl53ZchbtAtCZQCHROiD20W7UnKTQgWQrjTHAVNw1ic="))},
-                                                   {"alice@example.org", QByteArray::fromBase64(("QR05jrab7PFkSLhtdzyXrPfCqhkNCYCrlWATaBMTenE="))},
-                                                   {"bob@example.com", QByteArray::fromBase64(("GgTqeRLp1M+MEenzFQym2oqer9PfHukS4brJDQl5ARE="))}};
-    QMultiHash<QString, QByteArray> distrustedKeys = {{"alice@example.org", QByteArray::fromBase64(("mB98hhdVps++skUuy4TGy/Vp6RQXLJO4JGf86FAUjyc="))},
-                                                      {"alice@example.org", QByteArray::fromBase64(("7y1t0LnmNBeXJka43XejFPLrKtQlSFATrYmy7xHaKYU="))}};
+    QMultiHash<QString, QByteArray> trustedKeys = {
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("Wl53ZchbtAtCZQCHROiD20W7UnKTQgWQrjTHAVNw1ic="))},
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("QR05jrab7PFkSLhtdzyXrPfCqhkNCYCrlWATaBMTenE="))},
+        {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("GgTqeRLp1M+MEenzFQym2oqer9PfHukS4brJDQl5ARE="))}};
+    QMultiHash<QString, QByteArray> distrustedKeys = {
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("mB98hhdVps++skUuy4TGy/Vp6RQXLJO4JGf86FAUjyc="))},
+        {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("7y1t0LnmNBeXJka43XejFPLrKtQlSFATrYmy7xHaKYU="))}};
 
     QCOMPARE(wait(this, storage.keysForPostponedTrustDecisions(ns_omemo, {QByteArray::fromBase64(("Mp6Y4wOF3aMcl38lb/VNbdPF9ucGFqSx2eyaEsqyHKE="))})),
              QHash({std::pair(true, trustedKeys), std::pair(false, distrustedKeys)}));
 
-    distrustedKeys = {{"alice@example.org", QByteArray::fromBase64(("mB98hhdVps++skUuy4TGy/Vp6RQXLJO4JGf86FAUjyc="))},
-                      {"alice@example.org", QByteArray::fromBase64(("7y1t0LnmNBeXJka43XejFPLrKtQlSFATrYmy7xHaKYU="))},
-                      {"bob@example.com", QByteArray::fromBase64(("sD6ilugEBeKxPsdDEyX43LSGKHKWd5MFEdhT+4RpsxA="))},
-                      {"bob@example.com", QByteArray::fromBase64(("X5tJ1D5rEeaeQE8eqhBKAj4KUZGYe3x+iHifaTBY1kM="))}};
+    distrustedKeys = {{QStringLiteral("alice@example.org"), QByteArray::fromBase64(("mB98hhdVps++skUuy4TGy/Vp6RQXLJO4JGf86FAUjyc="))},
+                      {QStringLiteral("alice@example.org"), QByteArray::fromBase64(("7y1t0LnmNBeXJka43XejFPLrKtQlSFATrYmy7xHaKYU="))},
+                      {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("sD6ilugEBeKxPsdDEyX43LSGKHKWd5MFEdhT+4RpsxA="))},
+                      {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("X5tJ1D5rEeaeQE8eqhBKAj4KUZGYe3x+iHifaTBY1kM="))}};
 
     QCOMPARE(wait(this,
                   storage.keysForPostponedTrustDecisions(ns_omemo,
@@ -426,8 +485,8 @@ void TrustDbTest::atmTestKeysForPostponedTrustDecisions()
     // IL5iwDQwquH7yjb5RAiIP+nvYiBUsNCXtKB8IpKc9QU=.
     storage.addKeysForPostponedTrustDecisions(ns_omemo, QByteArray::fromBase64(("IL5iwDQwquH7yjb5RAiIP+nvYiBUsNCXtKB8IpKc9QU=")), {keyOwnerBobTrustedKeys});
 
-    trustedKeys = {{"bob@example.com", QByteArray::fromBase64(("sD6ilugEBeKxPsdDEyX43LSGKHKWd5MFEdhT+4RpsxA="))}};
-    distrustedKeys = {{"bob@example.com", QByteArray::fromBase64(("X5tJ1D5rEeaeQE8eqhBKAj4KUZGYe3x+iHifaTBY1kM="))}};
+    trustedKeys = {{QStringLiteral("bob@example.com"), QByteArray::fromBase64(("sD6ilugEBeKxPsdDEyX43LSGKHKWd5MFEdhT+4RpsxA="))}};
+    distrustedKeys = {{QStringLiteral("bob@example.com"), QByteArray::fromBase64(("X5tJ1D5rEeaeQE8eqhBKAj4KUZGYe3x+iHifaTBY1kM="))}};
 
     QCOMPARE(wait(this, storage.keysForPostponedTrustDecisions(ns_omemo, {QByteArray::fromBase64(("IL5iwDQwquH7yjb5RAiIP+nvYiBUsNCXtKB8IpKc9QU="))})),
              QHash({std::pair(true, trustedKeys), std::pair(false, distrustedKeys)}));
@@ -449,9 +508,9 @@ void TrustDbTest::atmTestKeysForPostponedTrustDecisions()
                                                   QByteArray::fromBase64(("QR05jrab7PFkSLhtdzyXrPfCqhkNCYCrlWATaBMTenE"
                                                                           "="))});
 
-    trustedKeys = {{"alice@example.org", QByteArray::fromBase64(("QR05jrab7PFkSLhtdzyXrPfCqhkNCYCrlWATaBMTenE="))}};
-    distrustedKeys = {{"alice@example.org", QByteArray::fromBase64(("7y1t0LnmNBeXJka43XejFPLrKtQlSFATrYmy7xHaKYU="))},
-                      {"bob@example.com", QByteArray::fromBase64(("X5tJ1D5rEeaeQE8eqhBKAj4KUZGYe3x+iHifaTBY1kM="))}};
+    trustedKeys = {{QStringLiteral("alice@example.org"), QByteArray::fromBase64(("QR05jrab7PFkSLhtdzyXrPfCqhkNCYCrlWATaBMTenE="))}};
+    distrustedKeys = {{QStringLiteral("alice@example.org"), QByteArray::fromBase64(("7y1t0LnmNBeXJka43XejFPLrKtQlSFATrYmy7xHaKYU="))},
+                      {QStringLiteral("bob@example.com"), QByteArray::fromBase64(("X5tJ1D5rEeaeQE8eqhBKAj4KUZGYe3x+iHifaTBY1kM="))}};
 
     QCOMPARE(wait(this, storage.keysForPostponedTrustDecisions(ns_omemo)), QHash({std::pair(true, trustedKeys), std::pair(false, distrustedKeys)}));
 
@@ -460,10 +519,10 @@ void TrustDbTest::atmTestKeysForPostponedTrustDecisions()
 
     QVERIFY(wait(this, storage.keysForPostponedTrustDecisions(ns_omemo)).isEmpty());
 
-    trustedKeys = {{("carol@example.net"), QByteArray::fromBase64(("WcL+cEMpEeK+dpqg3Xd3amctzwP8h2MqwXcEzFf6LpU="))},
-                   {("carol@example.net"), QByteArray::fromBase64(("bH3R31z0N97K1fUwG3+bdBrVPuDfXguQapHudkfa5nE="))}};
-    distrustedKeys = {{("carol@example.net"), QByteArray::fromBase64(("N0B2StHKk1/slwg1rzybTFzjdg7FChc+3cXmTU/rS8g="))},
-                      {("carol@example.net"), QByteArray::fromBase64(("wsEN32UHCiNjYqTG/J63hY4Nu8tZT42Ni1FxrgyRQ5g="))}};
+    trustedKeys = {{QStringLiteral("carol@example.net"), QByteArray::fromBase64(("WcL+cEMpEeK+dpqg3Xd3amctzwP8h2MqwXcEzFf6LpU="))},
+                   {QStringLiteral("carol@example.net"), QByteArray::fromBase64(("bH3R31z0N97K1fUwG3+bdBrVPuDfXguQapHudkfa5nE="))}};
+    distrustedKeys = {{QStringLiteral("carol@example.net"), QByteArray::fromBase64(("N0B2StHKk1/slwg1rzybTFzjdg7FChc+3cXmTU/rS8g="))},
+                      {QStringLiteral("carol@example.net"), QByteArray::fromBase64(("wsEN32UHCiNjYqTG/J63hY4Nu8tZT42Ni1FxrgyRQ5g="))}};
 
     // remaining OX keys
     QCOMPARE(wait(this, storage.keysForPostponedTrustDecisions(ns_ox)), QHash({std::pair(true, trustedKeys), std::pair(false, distrustedKeys)}));
@@ -477,13 +536,13 @@ void TrustDbTest::atmTestKeysForPostponedTrustDecisions()
 void TrustDbTest::atmTestResetAll()
 {
     QXmppTrustMessageKeyOwner keyOwnerAlice;
-    keyOwnerAlice.setJid("alice@example.org");
+    keyOwnerAlice.setJid(QStringLiteral("alice@example.org"));
     keyOwnerAlice.setTrustedKeys(
         {QByteArray::fromBase64(("Wl53ZchbtAtCZQCHROiD20W7UnKTQgWQrjTHAVNw1ic=")), QByteArray::fromBase64(("QR05jrab7PFkSLhtdzyXrPfCqhkNCYCrlWATaBMTenE="))});
     keyOwnerAlice.setDistrustedKeys({QByteArray::fromBase64(("mB98hhdVps++skUuy4TGy/Vp6RQXLJO4JGf86FAUjyc="))});
 
     QXmppTrustMessageKeyOwner keyOwnerBobTrustedKeys;
-    keyOwnerBobTrustedKeys.setJid("bob@example.com");
+    keyOwnerBobTrustedKeys.setJid(QStringLiteral("bob@example.com"));
     keyOwnerBobTrustedKeys.setTrustedKeys({QByteArray::fromBase64(("GgTqeRLp1M+MEenzFQym2oqer9PfHukS4brJDQl5ARE="))});
 
     storage.addKeysForPostponedTrustDecisions(ns_omemo,
@@ -491,7 +550,7 @@ void TrustDbTest::atmTestResetAll()
                                               {keyOwnerAlice, keyOwnerBobTrustedKeys});
 
     QXmppTrustMessageKeyOwner keyOwnerCarol;
-    keyOwnerCarol.setJid(("carol@example.net"));
+    keyOwnerCarol.setJid(QStringLiteral("carol@example.net"));
     keyOwnerCarol.setTrustedKeys(
         {QByteArray::fromBase64(("WcL+cEMpEeK+dpqg3Xd3amctzwP8h2MqwXcEzFf6LpU=")), QByteArray::fromBase64(("bH3R31z0N97K1fUwG3+bdBrVPuDfXguQapHudkfa5nE="))});
     keyOwnerCarol.setDistrustedKeys(
@@ -502,10 +561,12 @@ void TrustDbTest::atmTestResetAll()
     storage.resetAll(ns_omemo);
     QVERIFY(wait(this, storage.keysForPostponedTrustDecisions(ns_omemo)).isEmpty());
 
-    QMultiHash<QString, QByteArray> trustedKeys = {{("carol@example.net"), QByteArray::fromBase64(("WcL+cEMpEeK+dpqg3Xd3amctzwP8h2MqwXcEzFf6LpU="))},
-                                                   {("carol@example.net"), QByteArray::fromBase64(("bH3R31z0N97K1fUwG3+bdBrVPuDfXguQapHudkfa5nE="))}};
-    QMultiHash<QString, QByteArray> distrustedKeys = {{("carol@example.net"), QByteArray::fromBase64(("N0B2StHKk1/slwg1rzybTFzjdg7FChc+3cXmTU/rS8g="))},
-                                                      {("carol@example.net"), QByteArray::fromBase64(("wsEN32UHCiNjYqTG/J63hY4Nu8tZT42Ni1FxrgyRQ5g="))}};
+    QMultiHash<QString, QByteArray> trustedKeys = {
+        {QStringLiteral("carol@example.net"), QByteArray::fromBase64(("WcL+cEMpEeK+dpqg3Xd3amctzwP8h2MqwXcEzFf6LpU="))},
+        {QStringLiteral("carol@example.net"), QByteArray::fromBase64(("bH3R31z0N97K1fUwG3+bdBrVPuDfXguQapHudkfa5nE="))}};
+    QMultiHash<QString, QByteArray> distrustedKeys = {
+        {QStringLiteral("carol@example.net"), QByteArray::fromBase64(("N0B2StHKk1/slwg1rzybTFzjdg7FChc+3cXmTU/rS8g="))},
+        {QStringLiteral("carol@example.net"), QByteArray::fromBase64(("wsEN32UHCiNjYqTG/J63hY4Nu8tZT42Ni1FxrgyRQ5g="))}};
 
     QCOMPARE(wait(this, storage.keysForPostponedTrustDecisions(ns_ox)), QHash({std::pair(true, trustedKeys), std::pair(false, distrustedKeys)}));
 }
